/******************************************************************************
 *                                                                            *
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 *****************************************************************************
 * Originally developed and contributed by Ittiam Systems Pvt. Ltd, Bangalore
 */

#include "ixheaac_type_def.h"
#include "ixheaac_constants.h"
#include "ixheaace_aac_constants.h"
#include "ixheaace_sbr_header.h"
#include "ixheaace_sbr_def.h"
#include "ixheaace_resampler.h"
#include "ixheaace_sbr_hbe.h"
#include "ixheaace_sbr_rom.h"
#include "ixheaace_common_rom.h"
#include "ixheaace_sbr_main.h"

const FLOAT32 filter[IXHEAACE_INVF_SMOOTHING_LENGTH + 1] = {0.125f, 0.375f, 0.5f};

const WORD32 vector_offset_16k[] = {-8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7};

const WORD32 vector_offset_22k[] = {-5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13};

const WORD32 vector_offset_24k[] = {-5, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16};

const WORD32 vector_offset_32k[] = {-6, -4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16};

const WORD32 vector_offset_44_48_64[] = {-4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20};

const WORD32 vector_offset_88_96[] = {-2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20, 24};

const WORD32 vector_offset_def[] = {0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20, 24, 28, 33};

const WORD32 vector_stop_freq_32[14] = {32, 34, 36, 38, 40, 42, 44, 46, 49, 52, 55, 58, 61, 64};
const WORD32 vector_stop_freq_44[14] = {23, 25, 27, 29, 32, 34, 37, 40, 43, 47, 51, 55, 59, 64};
const WORD32 vector_stop_freq_48[14] = {21, 23, 25, 27, 30, 32, 35, 38, 42, 45, 49, 54, 59, 64};

const ixheaace_str_ps_tab ia_enhaacplus_enc_ps_tab = {
    /*a_hyb_res[3]*/
    {8, 4, 4},

    /*hi_res_band_borders*/
    {0, 1, 2, 3, 10, 11, 12, 13, 3, 4, 5, 6, 7, 8, 9, 11, 14, 18, 23, 35, 64},

    /*grp_borders_mix[28 + 1]*/
    {0,  1, 2, 3, 4, 5, 6, 7, 8,  9,  10, 11, 12, 13, 14,
     15, 3, 4, 5, 6, 7, 8, 9, 11, 14, 18, 23, 35, 64},

    /*shift_in_bins[20]*/
    {0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0},

    /*bins_2_goup_map[28 + 1]*/
    {0,
     1,
     2,
     3,
     4,
     4,
     (IXHEAACE_IPD_MASK_NEGATED | 1),
     (IXHEAACE_IPD_MASK_NEGATED | 0),
     6,
     3,
     4,
     5,
     6,
     7,
     8,
     5,
     8,
     9,
     10,
     11,
     12,
     13,
     14,
     15,
     16,
     17,
     18,
     19},

    /* p4_13 */
    {-0.0030515192f, 0.0079486230f, 0.0000000000f, -0.0431892388f, -0.1254244894f, 0.2122780681f,
     0.2500000000f, 0.2122780681f, 0.1254244894f, -0.0431892388f, 0.0000000000f, 0.0079486230f,
     0.0030515192f},

    /* p8_13 */
    {
        -0.0074608293f,
        -0.0227042101f,
        -0.0454686582f,
        -0.0726611391f,
        -0.0988510847f,
        0.1179371029f,
        0.1250000000f,
        0.1179371029f,
        0.0988510847f,
        0.0726611391f,
        0.0454686582f,
        0.0227042101f,
        0.0074608293f,
    },

    /* pan_class */
    {0.1660999954f, 0.4983000159f, 0.9135000110f, 1.4118000269f, 1.9931999445f, 2.6575999260f,
     3.5710999966f},

    /* sa_class */
    {0.0888999999f, 0.2298000008f, 0.3642500043f, 0.5044999719f, 0.6351000071f, 0.7996000051f,
     0.9456499815f},

    /*Huffman tables for PS*/

    /*a_book_ps_iid_time_code*/
    {0x0007FFF9, 0x0007FFFA, 0x0007FFFB, 0x000FFFF8, 0x000FFFF9, 0x000FFFFA,
     0x0001FFFD, 0x00007FFE, 0x00000FFE, 0x000003FE, 0x000000FE, 0x0000003E,
     0x0000000E, 0x00000002, 0x00000000, 0x00000006, 0x0000001E, 0x0000007E,
     0x000001FE, 0x000007FE, 0x00001FFE, 0x00003FFE, 0x0001FFFC, 0x0007FFF8,
     0x000FFFFB, 0x000FFFFC, 0x000FFFFD, 0x000FFFFE, 0x000FFFFF},

    /*a_book_ps_iid_time_length*/
    {0x13, 0x13, 0x13, 0x14, 0x14, 0x14, 0x11, 0x0F, 0x0C, 0x0A, 0x08, 0x06, 0x04, 0x02, 0x01,
     0x03, 0x05, 0x07, 0x09, 0x0B, 0x0D, 0x0E, 0x11, 0x13, 0x14, 0x14, 0x14, 0x14, 0x14},

    /*a_book_ps_iid_freq_code*/
    {0x0001FFFB, 0x0001FFFC, 0x0001FFFD, 0x0001FFFA, 0x0000FFFC, 0x00007FFC,
     0x00001FFD, 0x000003FE, 0x000001FE, 0x0000007E, 0x0000003C, 0x0000001D,
     0x0000000D, 0x00000005, 0x00000000, 0x00000004, 0x0000000C, 0x0000001C,
     0x0000003D, 0x0000003E, 0x000000FE, 0x000007FE, 0x00001FFC, 0x00003FFC,
     0x00003FFD, 0x00007FFD, 0x0001FFFE, 0x0003FFFE, 0x0003FFFF},

    /*a_book_ps_iid_freq_length*/
    {0x11, 0x11, 0x11, 0x11, 0x10, 0x0F, 0x0D, 0x0A, 0x09, 0x07, 0x06, 0x05, 0x04, 0x03, 0x01,
     0x03, 0x04, 0x05, 0x06, 0x06, 0x08, 0x0B, 0x0D, 0x0E, 0x0E, 0x0F, 0x11, 0x12, 0x12},

    /*a_book_ps_icc_time_code*/
    {0x3FFE, 0x1FFE, 0x07FE, 0x01FE, 0x007E, 0x001E, 0x0006, 0x0000, 0x0002, 0x000E, 0x003E,
     0x00FE, 0x03FE, 0x0FFE, 0x3FFF},

    /*a_book_ps_icc_time_length*/
    {0x0E, 0x0D, 0x0B, 0x09, 0x07, 0x05, 0x03, 0x01, 0x02, 0x04, 0x06, 0x08, 0x0A, 0x0C, 0x0E},

    /*a_book_ps_icc_freq_code[15]*/
    {0x3FFF, 0x3FFE, 0x0FFE, 0x03FE, 0x007E, 0x001E, 0x0006, 0x0000, 0x0002, 0x000E, 0x003E,
     0x00FE, 0x01FE, 0x07FE, 0x1FFE},

    /*a_book_ps_icc_freq_length[15]*/
    {0x0E, 0x0E, 0x0C, 0x0A, 0x07, 0x05, 0x03, 0x01, 0x02, 0x04, 0x06, 0x08, 0x09, 0x0B, 0x0D}};
/*End of PS Tables*/

const ixheaace_str_qmf_tabs ixheaace_qmf_tab = {
    /* sbr_qmf_64_640 */
    {
        0.0000000000f,  0.0132718220f, 0.3611589903f, -0.3611589903f, -0.0132718220f,
        0.0000000000f,  0.0132718220f, 0.3611589903f, -0.3611589903f, -0.0132718220f,
        -0.0005525286f, 0.0143904666f, 0.3723795546f, -0.3499914122f, -0.0121849995f,
        -0.0005525286f, 0.0143904666f, 0.3723795546f, -0.3499914122f, -0.0121849995f,
        -0.0005617692f, 0.0155405553f, 0.3836350013f, -0.3388722693f, -0.0111315548f,
        -0.0005617692f, 0.0155405553f, 0.3836350013f, -0.3388722693f, -0.0111315548f,
        -0.0004947518f, 0.0167324712f, 0.3949211761f, -0.3278113727f, -0.0101150215f,
        -0.0004947518f, 0.0167324712f, 0.3949211761f, -0.3278113727f, -0.0101150215f,
        -0.0004875227f, 0.0179433381f, 0.4062317676f, -0.3168278913f, -0.0091325329f,
        -0.0004875227f, 0.0179433381f, 0.4062317676f, -0.3168278913f, -0.0091325329f,
        -0.0004893791f, 0.0191872431f, 0.4175696896f, -0.3059098575f, -0.0081798233f,
        -0.0004893791f, 0.0191872431f, 0.4175696896f, -0.3059098575f, -0.0081798233f,
        -0.0005040714f, 0.0204531793f, 0.4289119920f, -0.2950716717f, -0.0072615816f,
        -0.0005040714f, 0.0204531793f, 0.4289119920f, -0.2950716717f, -0.0072615816f,
        -0.0005226564f, 0.0217467550f, 0.4402553754f, -0.2843214189f, -0.0063792293f,
        -0.0005226564f, 0.0217467550f, 0.4402553754f, -0.2843214189f, -0.0063792293f,
        -0.0005466565f, 0.0230680169f, 0.4515996535f, -0.2736634040f, -0.0055337211f,
        -0.0005466565f, 0.0230680169f, 0.4515996535f, -0.2736634040f, -0.0055337211f,
        -0.0005677802f, 0.0244160992f, 0.4629308085f, -0.2631053299f, -0.0047222596f,
        -0.0005677802f, 0.0244160992f, 0.4629308085f, -0.2631053299f, -0.0047222596f,
        -0.0005870930f, 0.0257875847f, 0.4742453214f, -0.2526480309f, -0.0039401124f,
        -0.0005870930f, 0.0257875847f, 0.4742453214f, -0.2526480309f, -0.0039401124f,
        -0.0006132747f, 0.0271859429f, 0.4855253091f, -0.2423016884f, -0.0031933778f,
        -0.0006132747f, 0.0271859429f, 0.4855253091f, -0.2423016884f, -0.0031933778f,
        -0.0006312493f, 0.0286072173f, 0.4967708254f, -0.2320690870f, -0.0024826723f,
        -0.0006312493f, 0.0286072173f, 0.4967708254f, -0.2320690870f, -0.0024826723f,
        -0.0006540333f, 0.0300502657f, 0.5079817500f, -0.2219652696f, -0.0018039472f,
        -0.0006540333f, 0.0300502657f, 0.5079817500f, -0.2219652696f, -0.0018039472f,
        -0.0006777690f, 0.0315017608f, 0.5191234970f, -0.2119735853f, -0.0011568135f,
        -0.0006777690f, 0.0315017608f, 0.5191234970f, -0.2119735853f, -0.0011568135f,
        -0.0006941614f, 0.0329754081f, 0.5302240895f, -0.2021250176f, -0.0005464280f,
        -0.0006941614f, 0.0329754081f, 0.5302240895f, -0.2021250176f, -0.0005464280f,
        -0.0007157736f, 0.0344620948f, 0.5412553448f, -0.1923966745f, 0.0000276045f,
        -0.0007157736f, 0.0344620948f, 0.5412553448f, -0.1923966745f, 0.0000276045f,
        -0.0007255043f, 0.0359697560f, 0.5522051258f, -0.1828172548f, 0.0005832264f,
        -0.0007255043f, 0.0359697560f, 0.5522051258f, -0.1828172548f, 0.0005832264f,
        -0.0007440941f, 0.0374812850f, 0.5630789140f, -0.1733808172f, 0.0010902329f,
        -0.0007440941f, 0.0374812850f, 0.5630789140f, -0.1733808172f, 0.0010902329f,
        -0.0007490598f, 0.0390053679f, 0.5738524131f, -0.1640958855f, 0.0015784682f,
        -0.0007490598f, 0.0390053679f, 0.5738524131f, -0.1640958855f, 0.0015784682f,
        -0.0007681371f, 0.0405349170f, 0.5845403235f, -0.1549607071f, 0.0020274176f,
        -0.0007681371f, 0.0405349170f, 0.5845403235f, -0.1549607071f, 0.0020274176f,
        -0.0007724848f, 0.0420649094f, 0.5951123086f, -0.1459766491f, 0.0024508540f,
        -0.0007724848f, 0.0420649094f, 0.5951123086f, -0.1459766491f, 0.0024508540f,
        -0.0007834332f, 0.0436097542f, 0.6055783538f, -0.1371551761f, 0.0028446757f,
        -0.0007834332f, 0.0436097542f, 0.6055783538f, -0.1371551761f, 0.0028446757f,
        -0.0007779869f, 0.0451488405f, 0.6159109932f, -0.1285002850f, 0.0032091885f,
        -0.0007779869f, 0.0451488405f, 0.6159109932f, -0.1285002850f, 0.0032091885f,
        -0.0007803664f, 0.0466843027f, 0.6261242695f, -0.1200077984f, 0.0035401246f,
        -0.0007803664f, 0.0466843027f, 0.6261242695f, -0.1200077984f, 0.0035401246f,
        -0.0007801449f, 0.0482165720f, 0.6361980107f, -0.1116826931f, 0.0038456408f,
        -0.0007801449f, 0.0482165720f, 0.6361980107f, -0.1116826931f, 0.0038456408f,
        -0.0007757977f, 0.0497385755f, 0.6461269695f, -0.1035329531f, 0.0041251642f,
        -0.0007757977f, 0.0497385755f, 0.6461269695f, -0.1035329531f, 0.0041251642f,
        -0.0007630793f, 0.0512556155f, 0.6559016302f, -0.0955533352f, 0.0043801861f,
        -0.0007630793f, 0.0512556155f, 0.6559016302f, -0.0955533352f, 0.0043801861f,
        -0.0007530001f, 0.0527630746f, 0.6655139880f, -0.0877547536f, 0.0046039530f,
        -0.0007530001f, 0.0527630746f, 0.6655139880f, -0.0877547536f, 0.0046039530f,
        -0.0007319357f, 0.0542452768f, 0.6749663190f, -0.0801372934f, 0.0048109469f,
        -0.0007319357f, 0.0542452768f, 0.6749663190f, -0.0801372934f, 0.0048109469f,
        -0.0007215391f, 0.0557173648f, 0.6842353293f, -0.0726943300f, 0.0049839687f,
        -0.0007215391f, 0.0557173648f, 0.6842353293f, -0.0726943300f, 0.0049839687f,
        -0.0006917937f, 0.0571616450f, 0.6933282376f, -0.0654409853f, 0.0051382275f,
        -0.0006917937f, 0.0571616450f, 0.6933282376f, -0.0654409853f, 0.0051382275f,
        -0.0006650415f, 0.0585915683f, 0.7022388719f, -0.0583705326f, 0.0052715758f,
        -0.0006650415f, 0.0585915683f, 0.7022388719f, -0.0583705326f, 0.0052715758f,
        -0.0006341594f, 0.0599837480f, 0.7109410426f, -0.0514804176f, 0.0053838975f,
        -0.0006341594f, 0.0599837480f, 0.7109410426f, -0.0514804176f, 0.0053838975f,
        -0.0005946118f, 0.0613455171f, 0.7194462634f, -0.0447806821f, 0.0054753783f,
        -0.0005946118f, 0.0613455171f, 0.7194462634f, -0.0447806821f, 0.0054753783f,
        -0.0005564576f, 0.0626857808f, 0.7277448900f, -0.0382776572f, 0.0055404363f,
        -0.0005564576f, 0.0626857808f, 0.7277448900f, -0.0382776572f, 0.0055404363f,
        -0.0005145572f, 0.0639715898f, 0.7358211758f, -0.0319531274f, 0.0055917128f,
        -0.0005145572f, 0.0639715898f, 0.7358211758f, -0.0319531274f, 0.0055917128f,
        -0.0004606325f, 0.0652247106f, 0.7436827863f, -0.0258227288f, 0.0056266114f,
        -0.0004606325f, 0.0652247106f, 0.7436827863f, -0.0258227288f, 0.0056266114f,
        -0.0004095121f, 0.0664367512f, 0.7513137456f, -0.0198834129f, 0.0056389199f,
        -0.0004095121f, 0.0664367512f, 0.7513137456f, -0.0198834129f, 0.0056389199f,
        -0.0003501175f, 0.0676075985f, 0.7587080760f, -0.0141288827f, 0.0056455196f,
        -0.0003501175f, 0.0676075985f, 0.7587080760f, -0.0141288827f, 0.0056455196f,
        -0.0002896981f, 0.0687043828f, 0.7658674865f, -0.0085711749f, 0.0056220643f,
        -0.0002896981f, 0.0687043828f, 0.7658674865f, -0.0085711749f, 0.0056220643f,
        -0.0002098337f, 0.0697630244f, 0.7727780881f, -0.0032086896f, 0.0055938023f,
        -0.0002098337f, 0.0697630244f, 0.7727780881f, -0.0032086896f, 0.0055938023f,
        -0.0001446380f, 0.0707628710f, 0.7794287519f, 0.0019765601f,  0.0055475714f,
        -0.0001446380f, 0.0707628710f, 0.7794287519f, 0.0019765601f,  0.0055475714f,
        -0.0000617334f, 0.0717002673f, 0.7858353120f, 0.0069636862f,  0.0054876040f,
        -0.0000617334f, 0.0717002673f, 0.7858353120f, 0.0069636862f,  0.0054876040f,
        0.0000134949f,  0.0725682583f, 0.7919735841f, 0.0117623832f,  0.0054196775f,
        0.0000134949f,  0.0725682583f, 0.7919735841f, 0.0117623832f,  0.0054196775f,
        0.0001094383f,  0.0733620255f, 0.7978466413f, 0.0163701258f,  0.0053471681f,
        0.0001094383f,  0.0733620255f, 0.7978466413f, 0.0163701258f,  0.0053471681f,
        0.0002043017f,  0.0741003642f, 0.8034485751f, 0.0207997072f,  0.0052461166f,
        0.0002043017f,  0.0741003642f, 0.8034485751f, 0.0207997072f,  0.0052461166f,
        0.0002949531f,  0.0747452558f, 0.8087695004f, 0.0250307561f,  0.0051407353f,
        0.0002949531f,  0.0747452558f, 0.8087695004f, 0.0250307561f,  0.0051407353f,
        0.0004026540f,  0.0753137336f, 0.8138191270f, 0.0290824006f,  0.0050393022f,
        0.0004026540f,  0.0753137336f, 0.8138191270f, 0.0290824006f,  0.0050393022f,
        0.0005107388f,  0.0758008358f, 0.8185776004f, 0.0329583930f,  0.0049137603f,
        0.0005107388f,  0.0758008358f, 0.8185776004f, 0.0329583930f,  0.0049137603f,
        0.0006239376f,  0.0761992479f, 0.8230419890f, 0.0366418116f,  0.0047932560f,
        0.0006239376f,  0.0761992479f, 0.8230419890f, 0.0366418116f,  0.0047932560f,
        0.0007458025f,  0.0764992170f, 0.8272275347f, 0.0401458278f,  0.0046606460f,
        0.0007458025f,  0.0764992170f, 0.8272275347f, 0.0401458278f,  0.0046606460f,
        0.0008608443f,  0.0767093490f, 0.8311038457f, 0.0434768782f,  0.0045209852f,
        0.0008608443f,  0.0767093490f, 0.8311038457f, 0.0434768782f,  0.0045209852f,
        0.0009885988f,  0.0768173975f, 0.8346937361f, 0.0466303305f,  0.0043730719f,
        0.0009885988f,  0.0768173975f, 0.8346937361f, 0.0466303305f,  0.0043730719f,
        0.0011250155f,  0.0768230011f, 0.8379717337f, 0.0495978676f,  0.0042264269f,
        0.0011250155f,  0.0768230011f, 0.8379717337f, 0.0495978676f,  0.0042264269f,
        0.0012577884f,  0.0767204924f, 0.8409541392f, 0.0524093821f,  0.0040819753f,
        0.0012577884f,  0.0767204924f, 0.8409541392f, 0.0524093821f,  0.0040819753f,
        0.0013902494f,  0.0765050718f, 0.8436238281f, 0.0550460034f,  0.0039207432f,
        0.0013902494f,  0.0765050718f, 0.8436238281f, 0.0550460034f,  0.0039207432f,
        0.0015443219f,  0.0761748321f, 0.8459818469f, 0.0575152691f,  0.0037603922f,
        0.0015443219f,  0.0761748321f, 0.8459818469f, 0.0575152691f,  0.0037603922f,
        0.0016868083f,  0.0757305756f, 0.8480315777f, 0.0598166570f,  0.0036008268f,
        0.0016868083f,  0.0757305756f, 0.8480315777f, 0.0598166570f,  0.0036008268f,
        0.0018348265f,  0.0751576255f, 0.8497805198f, 0.0619602779f,  0.0034418874f,
        0.0018348265f,  0.0751576255f, 0.8497805198f, 0.0619602779f,  0.0034418874f,
        0.0019841140f,  0.0744664394f, 0.8511971524f, 0.0639444805f,  0.0032739613f,
        0.0019841140f,  0.0744664394f, 0.8511971524f, 0.0639444805f,  0.0032739613f,
        0.0021461583f,  0.0736406005f, 0.8523047035f, 0.0657690668f,  0.0031125420f,
        0.0021461583f,  0.0736406005f, 0.8523047035f, 0.0657690668f,  0.0031125420f,
        0.0023017254f,  0.0726774642f, 0.8531020949f, 0.0674525021f,  0.0029469447f,
        0.0023017254f,  0.0726774642f, 0.8531020949f, 0.0674525021f,  0.0029469447f,
        0.0024625616f,  0.0715826364f, 0.8535720573f, 0.0689664013f,  0.0027870464f,
        0.0024625616f,  0.0715826364f, 0.8535720573f, 0.0689664013f,  0.0027870464f,
        0.0026201758f,  0.0703533073f, 0.8537385600f, 0.0703533073f,  0.0026201758f,
        0.0026201758f,  0.0703533073f, 0.8537385600f, 0.0703533073f,  0.0026201758f,
    },
    /* sbr_cld_fb */
    {
        0.0000006572f,  -0.0000080101f, -0.0012507428f, 0.0089963712f,  0.5128557086f,
        0.0000004118f,  -0.0000146993f, -0.0011947433f, 0.0096402988f,  0.5299509764f,
        0.0000008110f,  0.0000048406f,  -0.0011517958f, 0.0103312628f,  0.5470651984f,
        0.0000007100f,  0.0000071671f,  -0.0010990006f, 0.0110695893f,  0.5641523004f,
        0.0000006834f,  0.0000108833f,  -0.0010476547f, 0.0118621076f,  0.5811992884f,
        0.0000004293f,  0.0000101326f,  -0.0009862027f, 0.0127074700f,  0.5981877446f,
        -0.0000000054f, 0.0000058697f,  -0.0009294665f, 0.0136107206f,  0.6151031256f,
        0.0000000636f,  0.0000112513f,  -0.0009767709f, 0.0145620862f,  0.6319283843f,
        0.0000005491f,  0.0000201545f,  -0.0010405980f, 0.0155775947f,  0.6486437917f,
        0.0000016202f,  0.0000280046f,  -0.0011462684f, 0.0166518800f,  0.6652303934f,
        -0.0000000006f, 0.0000089760f,  -0.0012928658f, 0.0177824870f,  0.6816667914f,
        -0.0000000006f, 0.0000085638f,  -0.0011966380f, 0.0189750586f,  0.6979336739f,
        -0.0000000040f, 0.0000116889f,  -0.0009726699f, 0.0202352460f,  0.7140087485f,
        -0.0000000042f, 0.0000073006f,  -0.0008029620f, 0.0215630457f,  0.7298745513f,
        -0.0000000185f, 0.0000039654f,  -0.0006754936f, 0.0229647085f,  0.7455111742f,
        -0.0000000039f, 0.0000013749f,  -0.0005791145f, 0.0244343355f,  0.7609050870f,
        -0.0000000009f, 0.0000003799f,  -0.0004733148f, 0.0259795673f,  0.7760385871f,
        0.0000000530f,  0.0000044697f,  -0.0002998740f, 0.0276009068f,  0.7908995152f,
        0.0000000739f,  0.0000246188f,  0.0000788262f,  0.0293152556f,  0.8054701090f,
        0.0000000017f,  0.0000400527f,  0.0004708010f,  0.0311086122f,  0.8197387457f,
        0.0000002443f,  0.0000527298f,  0.0008089812f,  0.0329815112f,  0.8336863518f,
        0.0000000139f,  0.0000493939f,  0.0011271418f,  0.0349330008f,  0.8472987413f,
        -0.0000056905f, -0.0000425644f, 0.0014173667f,  0.0369634256f,  0.8605542779f,
        0.0000036291f,  0.0000658233f,  0.0017250297f,  0.0390713774f,  0.8734366894f,
        -0.0000000539f, 0.0000648192f,  0.0019480690f,  0.0412557013f,  0.8859232068f,
        0.0000001350f,  0.0000336800f,  0.0020334653f,  0.0435556844f,  0.8979958892f,
        0.0000000073f,  0.0000469425f,  0.0022391430f,  0.0459906831f,  0.9096310735f,
        0.0000002400f,  0.0000690442f,  0.0024704563f,  0.0484928489f,  0.9208194613f,
        0.0000003331f,  0.0000564310f,  0.0026304720f,  0.0510562062f,  0.9315441847f,
        0.0000004768f,  0.0000709589f,  0.0027030194f,  0.0536831319f,  0.9417975545f,
        0.0000003429f,  0.0000787259f,  0.0027291367f,  0.0563721918f,  0.9515674710f,
        0.0000086768f,  0.0002666445f,  0.0027197495f,  0.0591136329f,  0.9608519673f,
        0.0000272230f,  0.0005822201f,  0.0025309070f,  0.0619269274f,  0.9696426392f,
        0.0000003576f,  0.0000787035f,  0.0022255240f,  0.0648044869f,  0.9779404998f,
        0.0000006293f,  0.0000724510f,  0.0018919718f,  0.0677167475f,  0.9857387543f,
        0.0000010702f,  0.0000719415f,  0.0015571121f,  0.0706494823f,  0.9930379987f,
        -0.0000003226f, -0.0000767996f, 0.0011947306f,  0.0736055896f,  0.9998285770f,
        -0.0000000096f, -0.0000609337f, 0.0006415402f,  0.0765765011f,  1.0061092377f,
        -0.0000000891f, -0.0000172135f, 0.0001092526f,  0.0795557052f,  1.0118677616f,
        -0.0000228556f, -0.0000888230f, 0.0002934876f,  0.0825196207f,  1.0171000957f,
        0.0000101358f,  0.0000641866f,  0.0005721223f,  0.0854771584f,  1.0217988491f,
        -0.0000170694f, 0.0001769262f,  0.0006976561f,  0.0884181336f,  1.0259667635f,
        0.0000013567f,  0.0000220634f,  0.0007376101f,  0.0913359076f,  1.0296005011f,
        -0.0000000140f, -0.0000065389f, 0.0007154124f,  0.0942162424f,  1.0327129364f,
        0.0000000355f,  -0.0000105271f, 0.0007139920f,  0.0970523953f,  1.0353116989f,
        0.0000004211f,  -0.0000090754f, 0.0006944123f,  0.0998295769f,  1.0374222994f,
        0.0000005434f,  -0.0000174828f, 0.0006766320f,  0.1025397629f,  1.0390615463f,
        0.0000000823f,  -0.0000349829f, 0.0006887784f,  0.1051642001f,  1.0402623415f,
        0.0000001273f,  -0.0000448949f, 0.0006673250f,  0.1076972038f,  1.0410431623f,
        0.0000002543f,  -0.0000544982f, 0.0005970697f,  0.1101215631f,  1.0414344072f,
        0.0000006323f,  -0.0000587420f, 0.0004749931f,  0.1124296188f,  1.0414433479f,
        0.0000000280f,  -0.0000793451f, 0.0003189336f,  0.1146042272f,  1.0410865545f,
        0.0000005892f,  -0.0000803923f, 0.0001218226f,  0.1166399121f,  1.0403496027f,
        0.0000007302f,  -0.0000990763f, -0.0001324292f, 0.1185243130f,  1.0392279625f,
        -0.0000045186f, -0.0002217025f, -0.0004268575f, 0.1202545688f,  1.0376831293f,
        -0.0000035616f, -0.0002415166f, -0.0007804546f, 0.1218184009f,  1.0356944799f,
        -0.0000001075f, -0.0002123672f, -0.0011566802f, 0.1232131571f,  1.0332058668f,
        0.0000013233f,  -0.0002078299f, -0.0015258186f, 0.1244269609f,  1.0301986933f,
        0.0000033778f,  -0.0001885286f, -0.0019141147f, 0.1254605204f,  1.0266156197f,
        0.0000051616f,  -0.0001728673f, -0.0022928135f, 0.1262995601f,  1.0224702358f,
        0.0000059240f,  -0.0001744842f, -0.0026580421f, 0.1269415766f,  1.0177290440f,
        0.0000063102f,  -0.0001784193f, -0.0030004226f, 0.1273648292f,  1.0125083923f,
        0.0000033572f,  -0.0002131406f, -0.0033188581f, 0.1275561303f,  1.0068932772f,
        0.0000051891f,  -0.0002078886f, -0.0035974756f, 0.1274567544f,  1.0014630556f,
        0.0000041780f,  -0.0000466378f, -0.0038708516f, 0.1273590773f,  0.9927543998f,
        0.0000053648f,  -0.0000058893f, -0.0041351304f, 0.1272498667f,  0.9807691574f,
        0.0000040837f,  -0.0000177411f, -0.0043516676f, 0.1268280596f,  0.9690016508f,
        0.0000035676f,  -0.0000000260f, -0.0045171902f, 0.1261262000f,  0.9568885565f,
        0.0000032628f,  0.0000126064f,  -0.0046362276f, 0.1251477301f,  0.9443802834f,
        0.0000020411f,  0.0000236452f,  -0.0047043213f, 0.1238868684f,  0.9313874245f,
        -0.0000000257f, 0.0000280696f,  -0.0047225677f, 0.1223371401f,  0.9179666042f,
        0.0000002715f,  0.0000449392f,  -0.0046632765f, 0.1204854473f,  0.9041286111f,
        0.0000021509f,  0.0000540815f,  -0.0045548114f, 0.1183233336f,  0.8899474144f,
        0.0000058186f,  0.0000375963f,  -0.0043695536f, 0.1158358902f,  0.8754640818f,
        -0.0000000017f, 0.0000251512f,  -0.0040910328f, 0.1130179986f,  0.8607492447f,
        -0.0000000018f, 0.0000240652f,  -0.0037944254f, 0.1098551229f,  0.8458449841f,
        -0.0000000022f, 0.0000362851f,  -0.0034603628f, 0.1063454524f,  0.8308039904f,
        -0.0000000128f, 0.0000224155f,  -0.0030643111f, 0.1024804711f,  0.8156523108f,
        -0.0000000698f, 0.0000149917f,  -0.0026215371f, 0.0982625112f,  0.8004165292f,
        -0.0000000141f, 0.0000050099f,  -0.0021246478f, 0.0936865211f,  0.7851012349f,
        -0.0000000030f, 0.0000012772f,  -0.0015948609f, 0.0887575597f,  0.7697093487f,
        0.0000001876f,  0.0000158019f,  -0.0010614990f, 0.0834715068f,  0.7542294264f,
        0.0000001737f,  0.0000553395f,  -0.0006169855f, 0.0778329968f,  0.7386515141f,
        0.0000000038f,  0.0000887018f,  -0.0002004823f, 0.0718407407f,  0.7229599357f,
        0.0000005144f,  0.0001035783f,  0.0002048499f,  0.0655020922f,  0.7071447968f,
        0.0000000282f,  0.0000999076f,  0.0005621721f,  0.0588129684f,  0.6911981702f,
        0.0000046770f,  0.0001181078f,  0.0009373975f,  0.0517796464f,  0.6751199365f,
        0.0000033617f,  0.0000212636f,  0.0013446573f,  0.0443968400f,  0.6589148641f,
        -0.0000000488f, 0.0000586180f,  0.0018121761f,  0.0366694294f,  0.6425939798f,
        0.0000002268f,  0.0000502191f,  0.0021728661f,  0.0285752825f,  0.6261725426f,
        0.0000000052f,  0.0000415008f,  0.0019858254f,  0.0201223698f,  0.6096690297f,
        -0.0000002067f, 0.0000379997f,  0.0016976526f,  0.0113232406f,  0.5930981636f,
        0.0000004883f,  0.0000660646f,  0.0014711672f,  0.0021842569f,  0.5764734745f,
        0.0000008254f,  0.0000975569f,  0.0012321344f,  -0.0072981976f, 0.5598052144f,
        0.0000009465f,  0.0001831121f,  0.0008990256f,  -0.0171132404f, 0.5430990458f,
        -0.0000123269f, -0.0000005902f, 0.0006150317f,  -0.0272648428f, 0.5263554454f,
        0.0000386748f,  -0.0003595054f, 0.0006307841f,  -0.0377592817f, 0.5095720887f,
        -0.0000009871f, -0.0001815837f, 0.0004366447f,  -0.0485900566f, 0.4927463830f,
        -0.0000010895f, -0.0000920488f, 0.0001498232f,  -0.0597374178f, 0.4758753777f,
        -0.0000015690f, -0.0000519244f, -0.0000909972f, -0.0712035671f, 0.4589582980f,
        -0.0000002779f, 0.0000648788f,  -0.0003337967f, -0.0829810277f, 0.4420014024f,
        0.0000000068f,  0.0000539706f,  -0.0005599348f, -0.0950696692f, 0.4250144064f,
        0.0000001496f,  0.0000247202f,  -0.0007677634f, -0.1074630693f, 0.4080154896f,
        0.0000206830f,  0.0000971168f,  -0.0009730460f, -0.1201628670f, 0.3910244107f,
        -0.0000093890f, 0.0000514497f,  -0.0011318596f, -0.1331544966f, 0.3740643859f,
        -0.0000140293f, -0.0001039264f, -0.0012832807f, -0.1464389116f, 0.3571527898f,
        -0.0000027576f, 0.0000028534f,  -0.0014805426f, -0.1600061804f, 0.3403074145f,
        0.0000000295f,  0.0000133409f,  -0.0016991606f, -0.1738542169f, 0.3235298693f,
        -0.0000000787f, 0.0000244316f,  -0.0019248447f, -0.1879711747f, 0.3068186641f,
        -0.0000009897f, 0.0000356855f,  -0.0021523801f, -0.2023548037f, 0.2901491225f,
        -0.0000019221f, 0.0000619337f,  -0.0023964040f, -0.2169925719f, 0.2734977305f,
        -0.0000002766f, 0.0001176237f,  -0.0026538186f, -0.2318815440f, 0.2568176389f,
        -0.0000004636f, 0.0001635906f,  -0.0029271594f, -0.2470098287f, 0.2400768250f,
        -0.0000009607f, 0.0002060394f,  -0.0032090929f, -0.2623749077f, 0.2232276797f,
        -0.0000019079f, 0.0002346981f,  -0.0035055312f, -0.2779637873f, 0.2062605172f,
        -0.0000000155f, 0.0002520607f,  -0.0038116123f, -0.2937724888f, 0.1891590357f,
        -0.0000016535f, 0.0002556450f,  -0.0041336399f, -0.3097861707f, 0.1719726324f,
        -0.0000020435f, 0.0003157664f,  -0.0044489931f, -0.3259993792f, 0.1547461152f,
        0.0000162279f,  0.0006205676f,  -0.0047541917f, -0.3423942327f, 0.1376149803f,
        0.0000139522f,  0.0007847840f,  -0.0050638509f, -0.3589626551f, 0.1206924245f,
        0.0000004591f,  0.0009019129f,  -0.0053945696f, -0.3756821752f, 0.1042033061f,
        -0.0000062619f, 0.0010549633f,  -0.0057411031f, -0.3925409317f, 0.0882974491f,
        -0.0000160605f, 0.0010894289f,  -0.0061091785f, -0.4095160365f, 0.0732597858f,
        -0.0000246423f, 0.0011225031f,  -0.0065005026f, -0.4265950322f, 0.0591867752f,
        -0.0000297682f, 0.0011775151f,  -0.0069251410f, -0.4437530339f, 0.0463469587f,
        -0.0000317747f, 0.0012261131f,  -0.0073805437f, -0.4609828889f, 0.0345071889f,
        -0.0000437330f, 0.0012635693f,  -0.0078763934f, -0.4782650471f, 0.0235305969f,
        -0.0000329900f, 0.0012878190f,  -0.0084077492f, -0.4956175387f, 0.0112958020f,
    },

    /*sbr_p_64_640_qmf*/
    {-0.000579834f, -0.000488281f, -0.000518799f, -0.000549316f, -0.000610352f, -0.000640869f,
     -0.000701904f, -0.000732422f, -0.000762939f, -0.000793457f, -0.000793457f, -0.000793457f,
     -0.000793457f, -0.000762939f, -0.000732422f, -0.000671387f, -0.000610352f, -0.000518799f,
     -0.000427246f, -0.000305176f, -0.000152588f, 0.000000000f,  0.000152588f,  0.000366211f,
     0.000579834f,  0.000823975f,  0.001068115f,  0.001342773f,  0.001647949f,  0.001953125f,
     0.002258301f,  0.002563477f,  0.002899170f,  0.003234863f,  0.003540039f,  0.003875732f,
     0.004180908f,  0.004486084f,  0.004760742f,  0.005004883f,  0.005187988f,  0.005371094f,
     0.005493164f,  0.005584717f,  0.005584717f,  0.005554199f,  0.005432129f,  0.005218506f,
     0.004943848f,  0.004547119f,  0.004089355f,  0.003509521f,  0.002807617f,  0.001983643f,
     0.001037598f,  0.000000000f,  -0.001159668f, -0.002502441f, -0.003967285f, -0.005554199f,
     -0.007263184f, -0.009155273f, -0.011138916f, -0.013275146f, 0.015502930f,  0.017883301f,
     0.020416260f,  0.023010254f,  0.025756836f,  0.028564453f,  0.031463623f,  0.034423828f,
     0.037445068f,  0.040496826f,  0.043579102f,  0.046630859f,  0.049682617f,  0.052703857f,
     0.055664063f,  0.058532715f,  0.061309814f,  0.063934326f,  0.066375732f,  0.068664551f,
     0.070709229f,  0.072509766f,  0.074066162f,  0.075256348f,  0.076141357f,  0.076660156f,
     0.076782227f,  0.076446533f,  0.075683594f,  0.074432373f,  0.072631836f,  0.070312500f,
     0.067413330f,  0.063903809f,  0.059783936f,  0.054992676f,  0.049560547f,  0.043426514f,
     0.036590576f,  0.029022217f,  0.020751953f,  0.011718750f,  0.001922607f,  -0.008575439f,
     -0.019897461f, -0.031982422f, -0.044799805f, -0.058380127f, -0.072723389f, -0.087768555f,
     -0.103546143f, -0.120025635f, -0.137176514f, -0.154968262f, -0.173400879f, -0.192413330f,
     -0.211975098f, -0.232086182f, -0.252655029f, -0.273681641f, -0.295074463f, -0.316833496f,
     -0.338897705f, -0.361175537f, 0.383575439f,  0.406188965f,  0.428863525f,  0.451568604f,
     0.474212646f,  0.496734619f,  0.519073486f,  0.541198730f,  0.563018799f,  0.584503174f,
     0.605529785f,  0.626068115f,  0.646087646f,  0.665466309f,  0.684204102f,  0.702178955f,
     0.719390869f,  0.735778809f,  0.751281738f,  0.765808105f,  0.779388428f,  0.791931152f,
     0.803405762f,  0.813781738f,  0.822998047f,  0.831054688f,  0.837921143f,  0.843566895f,
     0.847991943f,  0.851165771f,  0.853057861f,  0.853698730f,  0.853057861f,  0.851165771f,
     0.847991943f,  0.843566895f,  0.837921143f,  0.831054688f,  0.822998047f,  0.813781738f,
     0.803405762f,  0.791931152f,  0.779388428f,  0.765808105f,  0.751281738f,  0.735778809f,
     0.719390869f,  0.702178955f,  0.684204102f,  0.665466309f,  0.646087646f,  0.626068115f,
     0.605529785f,  0.584503174f,  0.563018799f,  0.541198730f,  0.519073486f,  0.496734619f,
     0.474212646f,  0.451568604f,  0.428863525f,  0.406188965f,  0.383575439f,  0.361114502f,
     -0.338897705f, -0.316833496f, -0.295074463f, -0.273681641f, -0.252655029f, -0.232086182f,
     -0.211975098f, -0.192413330f, -0.173400879f, -0.154968262f, -0.137176514f, -0.120025635f,
     -0.103546143f, -0.087768555f, -0.072723389f, -0.058380127f, -0.044799805f, -0.031982422f,
     -0.019897461f, -0.008575439f, 0.001922607f,  0.011718750f,  0.020751953f,  0.029022217f,
     0.036590576f,  0.043426514f,  0.049560547f,  0.054992676f,  0.059783936f,  0.063903809f,
     0.067413330f,  0.070312500f,  0.072631836f,  0.074432373f,  0.075683594f,  0.076446533f,
     0.076782227f,  0.076660156f,  0.076141357f,  0.075256348f,  0.074066162f,  0.072509766f,
     0.070709229f,  0.068664551f,  0.066375732f,  0.063934326f,  0.061309814f,  0.058532715f,
     0.055664063f,  0.052703857f,  0.049682617f,  0.046630859f,  0.043579102f,  0.040496826f,
     0.037445068f,  0.034423828f,  0.031463623f,  0.028564453f,  0.025756836f,  0.023010254f,
     0.020416260f,  0.017883301f,  0.015502930f,  0.013214111f,  -0.011138916f, -0.009155273f,
     -0.007263184f, -0.005554199f, -0.003967285f, -0.002502441f, -0.001159668f, 0.000000000f,
     0.001037598f,  0.001983643f,  0.002807617f,  0.003509521f,  0.004089355f,  0.004547119f,
     0.004943848f,  0.005218506f,  0.005432129f,  0.005554199f,  0.005584717f,  0.005584717f,
     0.005493164f,  0.005371094f,  0.005187988f,  0.005004883f,  0.004760742f,  0.004486084f,
     0.004180908f,  0.003875732f,  0.003540039f,  0.003234863f,  0.002899170f,  0.002563477f,
     0.002258301f,  0.001953125f,  0.001647949f,  0.001342773f,  0.001068115f,  0.000823975f,
     0.000579834f,  0.000366211f,  0.000152588f,  0.000000000f,  -0.000152588f, -0.000305176f,
     -0.000427246f, -0.000518799f, -0.000610352f, -0.000671387f, -0.000732422f, -0.000762939f,
     -0.000793457f, -0.000793457f, -0.000793457f, -0.000793457f, -0.000762939f, -0.000732422f,
     -0.000701904f, -0.000640869f, -0.000610352f, -0.000549316f, -0.000518799f, -0.000488281f,
     -0.000579834f, -0.000030518f, -0.400024414f, -0.400024414f, -0.400024414f, -0.400024414f},

    /*sbr_alt_sin_twiddle*/
    {0.000000000f, 0.998809814f, 0.097991943f, 0.995147705f, 0.195068359f, 0.980743408f,
     0.290252686f, 0.956909180f, 0.382659912f, 0.923828125f, 0.471374512f, 0.881866455f,
     0.555541992f, 0.831420898f, 0.634368896f, 0.772979736f, 0.707061768f, 0.707061768f,
     0.000000000f},
    /*sbr_cos_sin_twiddle*/
    {0.999664307f, 0.024536133f, 0.992431641f, 0.122406006f, 0.975646973f, 0.219085693f,
     0.949493408f, 0.313659668f, 0.914154053f, 0.405212402f, 0.870056152f, 0.492858887f,
     0.817535400f, 0.575775146f, 0.757171631f, 0.653137207f, 0.689514160f, 0.724212646f,
     0.615203857f, 0.788299561f, 0.534973145f, 0.844818115f, 0.449584961f, 0.893188477f,
     0.359863281f, 0.932952881f, 0.266693115f, 0.963745117f, 0.170928955f, 0.985229492f,
     0.073547363f, 0.997253418f},

    /* cos_sin_fct_4_32 */
    {
        0.9996643066f, 0.0245361328f, 0.9972534180f, 0.0735473633f, 0.9924316406f, 0.1224060059f,
        0.9852294922f, 0.1709289551f, 0.9756469727f, 0.2190856934f, 0.9637451172f, 0.2666931152f,
        0.9494934082f, 0.3136596680f, 0.9329528809f, 0.3598632812f, 0.9141540527f, 0.4052124023f,
        0.8931884766f, 0.4495849609f, 0.8700561523f, 0.4928588867f, 0.8448181152f, 0.5349731445f,
        0.8175354004f, 0.5757751465f, 0.7882995605f, 0.6152038574f, 0.7571716309f, 0.6531372070f,
        0.7242126465f, 0.6895141602f,
    },
    /* cos_sin_fct4_16 */
    {
        0.9987487793f,
        0.0490417480f,
        0.9891357422f,
        0.1466979980f,
        0.9700012207f,
        0.2429504395f,
        0.9414978027f,
        0.3368530273f,
        0.9039611816f,
        0.4275207520f,
        0.8576965332f,
        0.5140686035f,
        0.8031616211f,
        0.5956726074f,
        0.7409057617f,
        0.6715087891f,
    },
    /* cos_sin_fct4_8 */
    {
        0.9951477051f,
        0.0979919434f,
        0.9569091797f,
        0.2902526855f,
        0.8818664551f,
        0.4713745117f,
        0.7729797363f,
        0.6343688965f,
    },

    /*ixheaace_str_det_params detector_params_aac*/
    {{1.0f, 10.0f, 14.0f, 19.0f},
     {0.0f, 3.0f, 7.0f, 10.0f},
     {25.0f, 30.0f, 35.0f, 40.0f},
     4,
     4,
     4,
     {{IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF,
       IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF,
       IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF}},
     {{IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_LOW_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF}},
     {-4, -3, -2, -1, 0}},

    /*ixheaace_str_det_params detector_params_aac_speech*/
    {{1.0f, 10.0f, 14.0f, 19.0f},
     {0.0f, 3.0f, 7.0f, 10.0f},
     {25.0f, 30.0f, 35.0f, 40.0f},
     4,
     4,
     4,
     {{IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF}},
     {{IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_LOW_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF},
      {IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_HIGH_LEVEL, IXHEAACE_INVF_MID_LEVEL,
       IXHEAACE_INVF_OFF, IXHEAACE_INVF_OFF}},
     {-4, -3, -2, -1, 0}},

    {1, {0, 16}, {FREQ_RES_HIGH}, 0, 1, {0, 16}},

    {2, {0, 8, 16}, {FREQ_RES_HIGH, FREQ_RES_HIGH}, 0, 2, {0, 8, 16}},

    {4,
     {0, 4, 8, 12, 16},
     {FREQ_RES_HIGH, FREQ_RES_HIGH, FREQ_RES_HIGH, FREQ_RES_HIGH},
     0,
     2,
     {0, 8, 16}},

    {1, {0, 15}, {FREQ_RES_HIGH}, 0, 1, {0, 15}},

    {2, {0, 8, 15}, {FREQ_RES_HIGH, FREQ_RES_HIGH}, 0, 2, {0, 8, 15}},

    {4,
     {0, 4, 8, 12, 15},
     {FREQ_RES_HIGH, FREQ_RES_HIGH, FREQ_RES_HIGH, FREQ_RES_HIGH},
     0,
     2,
     {0, 8, 15}},

    /* ptr_smooth_filter */
    {0.05857864376269f, 0.2f, 0.34142135623731f, 0.4f},

    {8000, 11025, 12000, 16000, 22050, 24000, 32000, 44100, 48000},
    {{{{8000, 10000, {7, 11}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {10000, 12000, {11, 13}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {12000, 48001, {14, 13}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{0}}},

     {{{8000, 10000, {5, 6}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {10000, 12000, {8, 12}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {12000, 66001, {12, 13}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{0}}},

     {{{8000, 10000, {4, 6}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {10000, 12000, {7, 11}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {12000, 72001, {11, 12}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{0}}},

     {{{8000, 10000, {1, 0}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {10000, 12000, {2, 6}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {12000, 16000, {4, 6}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {16000, 18000, {4, 8}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {18000, 22000, {6, 11}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {10, 12}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {12, 13}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 44000, {14, 13}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {44000, 96001, {15, 13}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{16000, 24000, {4, 1}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {24000, 28000, {8, 10}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {28000, 36000, {10, 12}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {13, 13}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {15, 13}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {15, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {15, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 192001, {15, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{8000, 11369, {1, 1}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {11369, 16000, {3, 4}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {16000, 18000, {3, 5}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {18000, 22000, {4, 8}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {7, 8}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {10, 9}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 44000, {11, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {44000, 132301, {13, 12}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{16000, 24000, {2, 1}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {24000, 28000, {5, 6}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {28000, 32000, {5, 8}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {32000, 36000, {7, 8}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {10, 9}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {12, 9}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {13, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {14, 12}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 264601, {14, 12}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{8000, 12000, {1, 1}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {12000, 16000, {3, 4}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {16000, 18000, {3, 5}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {18000, 22000, {4, 8}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {7, 8}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {10, 9}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 44000, {11, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {44000, 144001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{16000, 24000, {2, 1}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {24000, 28000, {5, 6}, 3, {1, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {28000, 36000, {7, 8}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {10, 9}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {12, 9}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {13, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {14, 12}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 288001, {15, 12}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{24000, 36000, {4, 4}, 3, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 60000, {7, 6}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 8}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 192001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 60000, {4, 4}, 3, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 80000, {7, 6}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {9, 8}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {11, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 384001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{24000, 36000, {4, 4}, 3, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 60000, {7, 6}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 8}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 264601, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 60000, {4, 4}, 3, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 80000, {7, 6}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {9, 8}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {11, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 529201, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{24000, 36000, {4, 9}, 3, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 60000, {7, 10}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 288001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 60000, {4, 9}, 3, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 80000, {7, 10}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {9, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {11, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 576001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}}

    },
    {{{{0}}},

     {{{0}}},

     {{{8000, 32000, {1, 0}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO}, {0}}, {{0}}},

     {{{16000, 18000, {4, 9}, 3, {1, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {18000, 22000, {7, 12}, 3, {1, 6, 9}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {6, 9}, 3, {2, 3, 6}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {8, 12}, 3, {2, 9, 12}, IXHEAACE_SBR_MODE_MONO},
       {36000, 44000, {10, 12}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {44000, 64001, {11, 13}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 36000, {10, 12}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {13, 13}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {10, 11}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {14, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {14, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 128001, {14, 13}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{18000, 22000, {4, 5}, 3, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {5, 6}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {7, 8}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 44000, {9, 9}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {44000, 52000, {12, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {52000, 64001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 36000, {5, 7}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {5, 8}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {7, 8}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {9, 9}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {10, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 82000, {12, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {82000, 128001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{20000, 22000, {3, 8}, 2, {2, 0, 6}, IXHEAACE_SBR_MODE_MONO},
       {22000, 28000, {3, 8}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {28000, 36000, {4, 8}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 56000, {8, 9}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {56000, 64001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{32000, 36000, {5, 7}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {36000, 44000, {4, 8}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {44000, 52000, {6, 8}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {52000, 60000, {9, 9}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {60000, 76000, {11, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {76000, 88000, {12, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {88000, 128001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{24000, 36000, {4, 4}, 3, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {36000, 60000, {7, 6}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 8}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 160001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{60000, 80000, {7, 6}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {9, 8}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {11, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 256001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{36000, 60000, {8, 6}, 2, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 160001, {13, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{60000, 80000, {7, 6}, 2, {3, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {10, 8}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {12, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 256001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}},

     {{{36000, 60000, {4, 4}, 3, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {60000, 72000, {9, 10}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {72000, 100000, {11, 11}, 1, {2, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {100000, 160001, {13, 11}, 1, {1, 0, 3}, IXHEAACE_SBR_MODE_MONO},
       {0}},
      {{60000, 80000, {7, 10}, 2, {2, 0, -3}, IXHEAACE_SBR_MODE_SWITCH_LRC},
       {80000, 112000, {9, 10}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {112000, 144000, {11, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {144000, 176000, {12, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {176000, 256001, {13, 11}, 1, {3, 0, -3}, IXHEAACE_SBR_MODE_LEFT_RIGHT},
       {0}}}}

};
/*End of QMF Tables*/

/*Resampler Tables*/

const ixheaace_resampler_table ixheaace_resamp_2_to_1_iir_filt_params = {
    /*This is an Elliptic Low pass filter of order 10.
     *Cutoff frequency = (Sampling frequency / 4) (12000Hz for Sampling Frequency of 48000Hz)
     *Transition Width = 12000Hz for Sampling Frequency of 48000Hz
     *Pass band ripple = 0.1 dB
     *Stop band Attentuation = 80 dB */
    {{0.009496807693824f, 0.042966063118977f, 0.117336448672214f, 0.222712964327863f,
      0.321217815735198f, 0.361496789441669f},
     {1.000000000000000f, -1.742132866454912f, 4.227908023609383f, -5.182642233547811f,
      6.412608818570662f, -5.548549002499044f, 4.268395360082115f, -2.482474601928258f,
      1.157341917316495f, -0.375865524201107f, 0.075082243212013f},
     14,
     8}};

const ixheaace_resampler_table ixheaace_resamp_4_to_1_iir_filt_params = {
    /*This is an Elliptic Low pass filter of order 10.
     *Cutoff frequency = (Sampling frequency / 8) (6000Hz for Sampling Frequency of 48000Hz)
     *Transition Width = 6000Hz for Sampling Frequency of 48000Hz
     *Pass band ripple = 0.1 dB
     *Stop band Attentuation = 80 dB */
    {{0.000740642396154f, -0.001731221748871f, 0.003588738327167f, -0.003965395503334f,
      0.004738151506581f, -0.003995960744935f},
     {1.000000000000000f, -7.075216005247155f, 23.952949728863750f, -50.605428582325821f,
      73.504548294113960f, -76.448633221533086f, 57.543830222794064f, -30.920504724587701f,
      11.348197853288209f, -2.570137091297488f, 0.273171190808642f},
     14,
     16}};

const ixheaace_resampler_sos_table iixheaace_resamp_1_to_3_filt_params = {
    /*This is an Elliptic Low pass filter of order 10.
     *Cutoff frequency = (Sampling frequency / 2) (24000Hz for Sampling Frequency of 48000Hz)
     *Transition Width = 24000Hz for Sampling Frequency of 48000Hz
     *Pass band ripple = 0.1 dB
     *Stop band Attentuation = 80 dB */
    {{{1.000000000000000f, 1.659020203326806f, 1.000000000000001f},
      {1.000000000000000f, 0.365127296282968f, 1.000000000000001f},
      {1.000000000000000f, -0.326327243355117f, 0.999999999999999f},
      {1.000000000000000f, -0.603095584059535f, 1.000000000000005f},
      {1.000000000000000f, -0.700775842024946f, 0.999999999999992f}},
     {{1.000000000000000f, -1.275111522510104f, 0.441657460172090f},
      {1.000000000000000f, -1.161824505687894f, 0.591325642736637f},
      {1.000000000000000f, -1.035133043687516f, 0.764152858071238f},
      {1.000000000000000f, -0.955952271048153f, 0.887794455980374f},
      {1.000000000000000f, -0.931430519187696f, 0.967382013429856f}},
     0.001893122993530f,
     12}};

const ixheaace_resampler_sos_table iixheaace_resamp_8_to_1_filt_params = {
    /*This is an Elliptic Low pass filter of order 10.
     *Cutoff frequency = (Sampling frequency / 16)(3000Hz for Sampling Frequency of 48000Hz)
     *Transition Width = 3000Hz for Sampling Frequency of 48000Hz
     *Pass band ripple = 0.1 dB
     *Stop band Attentuation = 80 dB */
    {{{1.000000000000000f, 0.193271530567190f, 0.999999999999997f},
      {1.000000000000000f, -1.437439768166423f, 1.000000000001828f},
      {1.000000000000000f, -1.698948126297796f, 0.999999999971090f},
      {1.000000000000000f, -1.771069098672357f, 1.000000000092826f},
      {1.000000000000000f, -1.793554586740388f, 0.999999999934263f}},
     {{1.000000000000000f, -1.734333859661148f, 0.758556958319196f},
      {1.000000000000000f, -1.758123207730125f, 0.821293076682905f},
      {1.000000000000000f, -1.787138197078451f, 0.895638469061020f},
      {1.000000000000000f, -1.810681327149778f, 0.950090642514994f},
      {1.000000000000000f, -1.831249067127384f, 0.985554959459442f}},
     0.000201109407457f,
     31}};

/*End of Resampler Tables*/
const ixheaace_str_sbr_huff_tabs ixheaace_sbr_huff_tab = {
    /*v_huff_env_lvl_c10t[121]*/
    {0x0003FFD6, 0x0003FFD7, 0x0003FFD8, 0x0003FFD9, 0x0003FFDA, 0x0003FFDB, 0x0007FFB8,
     0x0007FFB9, 0x0007FFBA, 0x0007FFBB, 0x0007FFBC, 0x0007FFBD, 0x0007FFBE, 0x0007FFBF,
     0x0007FFC0, 0x0007FFC1, 0x0007FFC2, 0x0007FFC3, 0x0007FFC4, 0x0007FFC5, 0x0007FFC6,
     0x0007FFC7, 0x0007FFC8, 0x0007FFC9, 0x0007FFCA, 0x0007FFCB, 0x0007FFCC, 0x0007FFCD,
     0x0007FFCE, 0x0007FFCF, 0x0007FFD0, 0x0007FFD1, 0x0007FFD2, 0x0007FFD3, 0x0001FFE6,
     0x0003FFD4, 0x0000FFF0, 0x0001FFE9, 0x0003FFD5, 0x0001FFE7, 0x0000FFF1, 0x0000FFEC,
     0x0000FFED, 0x0000FFEE, 0x00007FF4, 0x00003FF9, 0x00003FF7, 0x00001FFA, 0x00001FF9,
     0x00000FFB, 0x000007FC, 0x000003FC, 0x000001FD, 0x000000FD, 0x0000007D, 0x0000003D,
     0x0000001D, 0x0000000D, 0x00000005, 0x00000001, 0x00000000, 0x00000004, 0x0000000C,
     0x0000001C, 0x0000003C, 0x0000007C, 0x000000FC, 0x000001FC, 0x000003FD, 0x00000FFA,
     0x00001FF8, 0x00003FF6, 0x00003FF8, 0x00007FF5, 0x0000FFEF, 0x0001FFE8, 0x0000FFF2,
     0x0007FFD4, 0x0007FFD5, 0x0007FFD6, 0x0007FFD7, 0x0007FFD8, 0x0007FFD9, 0x0007FFDA,
     0x0007FFDB, 0x0007FFDC, 0x0007FFDD, 0x0007FFDE, 0x0007FFDF, 0x0007FFE0, 0x0007FFE1,
     0x0007FFE2, 0x0007FFE3, 0x0007FFE4, 0x0007FFE5, 0x0007FFE6, 0x0007FFE7, 0x0007FFE8,
     0x0007FFE9, 0x0007FFEA, 0x0007FFEB, 0x0007FFEC, 0x0007FFED, 0x0007FFEE, 0x0007FFEF,
     0x0007FFF0, 0x0007FFF1, 0x0007FFF2, 0x0007FFF3, 0x0007FFF4, 0x0007FFF5, 0x0007FFF6,
     0x0007FFF7, 0x0007FFF8, 0x0007FFF9, 0x0007FFFA, 0x0007FFFB, 0x0007FFFC, 0x0007FFFD,
     0x0007FFFE, 0x0007FFFF},

    /*v_huff_env_lvl_l10t*/
    {0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000011,
     0x00000012, 0x00000010, 0x00000011, 0x00000012, 0x00000011, 0x00000010, 0x00000010,
     0x00000010, 0x00000010, 0x0000000F, 0x0000000E, 0x0000000E, 0x0000000D, 0x0000000D,
     0x0000000C, 0x0000000B, 0x0000000A, 0x00000009, 0x00000008, 0x00000007, 0x00000006,
     0x00000005, 0x00000004, 0x00000003, 0x00000002, 0x00000002, 0x00000003, 0x00000004,
     0x00000005, 0x00000006, 0x00000007, 0x00000008, 0x00000009, 0x0000000A, 0x0000000C,
     0x0000000D, 0x0000000E, 0x0000000E, 0x0000000F, 0x00000010, 0x00000011, 0x00000010,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013},

    /*v_huff_env_lvl_c10f*/
    {0x0007FFE7, 0x0007FFE8, 0x000FFFD2, 0x000FFFD3, 0x000FFFD4, 0x000FFFD5, 0x000FFFD6,
     0x000FFFD7, 0x000FFFD8, 0x0007FFDA, 0x000FFFD9, 0x000FFFDA, 0x000FFFDB, 0x000FFFDC,
     0x0007FFDB, 0x000FFFDD, 0x0007FFDC, 0x0007FFDD, 0x000FFFDE, 0x0003FFE4, 0x000FFFDF,
     0x000FFFE0, 0x000FFFE1, 0x0007FFDE, 0x000FFFE2, 0x000FFFE3, 0x000FFFE4, 0x0007FFDF,
     0x000FFFE5, 0x0007FFE0, 0x0003FFE8, 0x0007FFE1, 0x0003FFE0, 0x0003FFE9, 0x0001FFEF,
     0x0003FFE5, 0x0001FFEC, 0x0001FFED, 0x0001FFEE, 0x0000FFF4, 0x0000FFF3, 0x0000FFF0,
     0x00007FF7, 0x00007FF6, 0x00003FFA, 0x00001FFA, 0x00001FF9, 0x00000FFA, 0x00000FF8,
     0x000007F9, 0x000003FB, 0x000001FC, 0x000001FA, 0x000000FB, 0x0000007C, 0x0000003C,
     0x0000001C, 0x0000000C, 0x00000005, 0x00000001, 0x00000000, 0x00000004, 0x0000000D,
     0x0000001D, 0x0000003D, 0x000000FA, 0x000000FC, 0x000001FB, 0x000003FA, 0x000007F8,
     0x000007FA, 0x000007FB, 0x00000FF9, 0x00000FFB, 0x00001FF8, 0x00001FFB, 0x00003FF8,
     0x00003FF9, 0x0000FFF1, 0x0000FFF2, 0x0001FFEA, 0x0001FFEB, 0x0003FFE1, 0x0003FFE2,
     0x0003FFEA, 0x0003FFE3, 0x0003FFE6, 0x0003FFE7, 0x0003FFEB, 0x000FFFE6, 0x0007FFE2,
     0x000FFFE7, 0x000FFFE8, 0x000FFFE9, 0x000FFFEA, 0x000FFFEB, 0x000FFFEC, 0x0007FFE3,
     0x000FFFED, 0x000FFFEE, 0x000FFFEF, 0x000FFFF0, 0x0007FFE4, 0x000FFFF1, 0x0003FFEC,
     0x000FFFF2, 0x000FFFF3, 0x0007FFE5, 0x0007FFE6, 0x000FFFF4, 0x000FFFF5, 0x000FFFF6,
     0x000FFFF7, 0x000FFFF8, 0x000FFFF9, 0x000FFFFA, 0x000FFFFB, 0x000FFFFC, 0x000FFFFD,
     0x000FFFFE, 0x000FFFFF

    },

    /*v_huff_env_lvl_l10f*/
    {0x00000013, 0x00000013, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014,
     0x00000014, 0x00000014, 0x00000013, 0x00000014, 0x00000014, 0x00000014, 0x00000014,
     0x00000013, 0x00000014, 0x00000013, 0x00000013, 0x00000014, 0x00000012, 0x00000014,
     0x00000014, 0x00000014, 0x00000013, 0x00000014, 0x00000014, 0x00000014, 0x00000013,
     0x00000014, 0x00000013, 0x00000012, 0x00000013, 0x00000012, 0x00000012, 0x00000011,
     0x00000012, 0x00000011, 0x00000011, 0x00000011, 0x00000010, 0x00000010, 0x00000010,
     0x0000000F, 0x0000000F, 0x0000000E, 0x0000000D, 0x0000000D, 0x0000000C, 0x0000000C,
     0x0000000B, 0x0000000A, 0x00000009, 0x00000009, 0x00000008, 0x00000007, 0x00000006,
     0x00000005, 0x00000004, 0x00000003, 0x00000002, 0x00000002, 0x00000003, 0x00000004,
     0x00000005, 0x00000006, 0x00000008, 0x00000008, 0x00000009, 0x0000000A, 0x0000000B,
     0x0000000B, 0x0000000B, 0x0000000C, 0x0000000C, 0x0000000D, 0x0000000D, 0x0000000E,
     0x0000000E, 0x00000010, 0x00000010, 0x00000011, 0x00000011, 0x00000012, 0x00000012,
     0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000014, 0x00000013,
     0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000013,
     0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000013, 0x00000014, 0x00000012,
     0x00000014, 0x00000014, 0x00000013, 0x00000013, 0x00000014, 0x00000014, 0x00000014,
     0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014,
     0x00000014, 0x00000014},

    /*book_sbr_env_bal_c10t*/
    {0x0000FFE4, 0x0000FFE5, 0x0000FFE6, 0x0000FFE7, 0x0000FFE8, 0x0000FFE9, 0x0000FFEA,
     0x0000FFEB, 0x0000FFEC, 0x0000FFED, 0x0000FFEE, 0x0000FFEF, 0x0000FFF0, 0x0000FFF1,
     0x0000FFF2, 0x0000FFF3, 0x0000FFF4, 0x0000FFE2, 0x00000FFC, 0x000007FC, 0x000001FE,
     0x0000007E, 0x0000001E, 0x00000006, 0x00000000, 0x00000002, 0x0000000E, 0x0000003E,
     0x000000FE, 0x000007FD, 0x00000FFD, 0x00007FF0, 0x0000FFE3, 0x0000FFF5, 0x0000FFF6,
     0x0000FFF7, 0x0000FFF8, 0x0000FFF9, 0x0000FFFA, 0x0001FFF6, 0x0001FFF7, 0x0001FFF8,
     0x0001FFF9, 0x0001FFFA, 0x0001FFFB, 0x0001FFFC, 0x0001FFFD, 0x0001FFFE, 0x0001FFFF},

    /*book_sbr_env_bal_l10t*/
    {

        0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010,
        0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000010,
        0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x0000000C, 0x0000000B, 0x00000009,
        0x00000007, 0x00000005, 0x00000003, 0x00000001, 0x00000002, 0x00000004, 0x00000006,
        0x00000008, 0x0000000B, 0x0000000C, 0x0000000F, 0x00000010, 0x00000010, 0x00000010,
        0x00000010, 0x00000010, 0x00000010, 0x00000010, 0x00000011, 0x00000011, 0x00000011,
        0x00000011, 0x00000011, 0x00000011, 0x00000011, 0x00000011, 0x00000011, 0x00000011},

    /*book_sbr_env_bal_c10f*/
    {0x0003FFE2, 0x0003FFE3, 0x0003FFE4, 0x0003FFE5, 0x0003FFE6, 0x0003FFE7, 0x0003FFE8,
     0x0003FFE9, 0x0003FFEA, 0x0003FFEB, 0x0003FFEC, 0x0003FFED, 0x0003FFEE, 0x0003FFEF,
     0x0003FFF0, 0x0000FFF7, 0x0001FFF0, 0x00003FFC, 0x000007FE, 0x000007FC, 0x000000FE,
     0x0000007E, 0x0000000E, 0x00000002, 0x00000000, 0x00000006, 0x0000001E, 0x0000003E,
     0x000001FE, 0x000007FD, 0x00000FFE, 0x00007FFA, 0x0000FFF6, 0x0003FFF1, 0x0003FFF2,
     0x0003FFF3, 0x0003FFF4, 0x0003FFF5, 0x0003FFF6, 0x0003FFF7, 0x0003FFF8, 0x0003FFF9,
     0x0003FFFA, 0x0003FFFB, 0x0003FFFC, 0x0003FFFD, 0x0003FFFE, 0x0007FFFE, 0x0007FFFF},

    /*book_sbr_env_bal_l10f*/
    {0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012,
     0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012,
     0x00000012, 0x00000010, 0x00000011, 0x0000000E, 0x0000000B, 0x0000000B, 0x00000008,
     0x00000007, 0x00000004, 0x00000002, 0x00000001, 0x00000003, 0x00000005, 0x00000006,
     0x00000009, 0x0000000B, 0x0000000C, 0x0000000F, 0x00000010, 0x00000012, 0x00000012,
     0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012,
     0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000012, 0x00000013, 0x00000013},

    /*v_huff_env_lvl_c11t*/
    {0x0003FFED, 0x0003FFEE, 0x0007FFDE, 0x0007FFDF, 0x0007FFE0, 0x0007FFE1, 0x0007FFE2,
     0x0007FFE3, 0x0007FFE4, 0x0007FFE5, 0x0007FFE6, 0x0007FFE7, 0x0007FFE8, 0x0007FFE9,
     0x0007FFEA, 0x0007FFEB, 0x0007FFEC, 0x0001FFF4, 0x0000FFF7, 0x0000FFF9, 0x0000FFF8,
     0x00003FFB, 0x00003FFA, 0x00003FF8, 0x00001FFA, 0x00000FFC, 0x000007FC, 0x000000FE,
     0x0000003E, 0x0000000E, 0x00000002, 0x00000000, 0x00000006, 0x0000001E, 0x0000007E,
     0x000001FE, 0x000007FD, 0x00001FFB, 0x00003FF9, 0x00003FFC, 0x00007FFA, 0x0000FFF6,
     0x0001FFF5, 0x0003FFEC, 0x0007FFED, 0x0007FFEE, 0x0007FFEF, 0x0007FFF0, 0x0007FFF1,
     0x0007FFF2, 0x0007FFF3, 0x0007FFF4, 0x0007FFF5, 0x0007FFF6, 0x0007FFF7, 0x0007FFF8,
     0x0007FFF9, 0x0007FFFA, 0x0007FFFB, 0x0007FFFC, 0x0007FFFD, 0x0007FFFE, 0x0007FFFF},

    /*v_huff_env_lvl_l11t*/
    {0x00000012, 0x00000012, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000011, 0x00000010, 0x00000010, 0x00000010,
     0x0000000E, 0x0000000E, 0x0000000E, 0x0000000D, 0x0000000C, 0x0000000B, 0x00000008,
     0x00000006, 0x00000004, 0x00000002, 0x00000001, 0x00000003, 0x00000005, 0x00000007,
     0x00000009, 0x0000000B, 0x0000000D, 0x0000000E, 0x0000000E, 0x0000000F, 0x00000010,
     0x00000011, 0x00000012, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013,
     0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000013},

    /*v_huff_env_lvl_c11f*/
    {0x000FFFF0, 0x000FFFF1, 0x000FFFF2, 0x000FFFF3, 0x000FFFF4, 0x000FFFF5, 0x000FFFF6,
     0x0003FFF3, 0x0007FFF5, 0x0007FFEE, 0x0007FFEF, 0x0007FFF6, 0x0003FFF4, 0x0003FFF2,
     0x000FFFF7, 0x0007FFF0, 0x0001FFF5, 0x0003FFF0, 0x0001FFF4, 0x0000FFF7, 0x0000FFF6,
     0x00007FF8, 0x00003FFB, 0x00000FFD, 0x000007FD, 0x000003FD, 0x000001FD, 0x000000FD,
     0x0000003E, 0x0000000E, 0x00000002, 0x00000000, 0x00000006, 0x0000001E, 0x000000FC,
     0x000001FC, 0x000003FC, 0x000007FC, 0x00000FFC, 0x00001FFC, 0x00003FFA, 0x00007FF9,
     0x00007FFA, 0x0000FFF8, 0x0000FFF9, 0x0001FFF6, 0x0001FFF7, 0x0003FFF5, 0x0003FFF6,
     0x0003FFF1, 0x000FFFF8, 0x0007FFF1, 0x0007FFF2, 0x0007FFF3, 0x000FFFF9, 0x0007FFF7,
     0x0007FFF4, 0x000FFFFA, 0x000FFFFB, 0x000FFFFC, 0x000FFFFD, 0x000FFFFE, 0x000FFFFF},

    /*v_huff_env_lvl_l11f*/
    {0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014,
     0x00000012, 0x00000013, 0x00000013, 0x00000013, 0x00000013, 0x00000012, 0x00000012,
     0x00000014, 0x00000013, 0x00000011, 0x00000012, 0x00000011, 0x00000010, 0x00000010,
     0x0000000F, 0x0000000E, 0x0000000C, 0x0000000B, 0x0000000A, 0x00000009, 0x00000008,
     0x00000006, 0x00000004, 0x00000002, 0x00000001, 0x00000003, 0x00000005, 0x00000008,
     0x00000009, 0x0000000A, 0x0000000B, 0x0000000C, 0x0000000D, 0x0000000E, 0x0000000F,
     0x0000000F, 0x00000010, 0x00000010, 0x00000011, 0x00000011, 0x00000012, 0x00000012,
     0x00000012, 0x00000014, 0x00000013, 0x00000013, 0x00000013, 0x00000014, 0x00000013,
     0x00000013, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014, 0x00000014},

    /*book_sbr_env_bal_c11t*/
    {0x00001FF2, 0x00001FF3, 0x00001FF4, 0x00001FF5, 0x00001FF6, 0x00001FF7, 0x00001FF8,
     0x00000FF8, 0x000000FE, 0x0000007E, 0x0000000E, 0x00000006, 0x00000000, 0x00000002,
     0x0000001E, 0x0000003E, 0x000001FE, 0x00001FF9, 0x00001FFA, 0x00001FFB, 0x00001FFC,
     0x00001FFD, 0x00001FFE, 0x00003FFE, 0x00003FFF},

    /*book_sbr_env_bal_l11t*/
    {0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000C, 0x00000008, 0x00000007, 0x00000004, 0x00000003, 0x00000001, 0x00000002,
     0x00000005, 0x00000006, 0x00000009, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000E, 0x0000000E

    },

    /*book_sbr_env_bal_c11f*/
    {0x00001FF7, 0x00001FF8, 0x00001FF9, 0x00001FFA, 0x00001FFB, 0x00003FF8, 0x00003FF9,
     0x000007FC, 0x000000FE, 0x0000007E, 0x0000000E, 0x00000002, 0x00000000, 0x00000006,
     0x0000001E, 0x0000003E, 0x000001FE, 0x00000FFA, 0x00001FF6, 0x00003FFA, 0x00003FFB,
     0x00003FFC, 0x00003FFD, 0x00003FFE, 0x00003FFF

    },

    /*book_sbr_env_bal_l11f*/
    {0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000E, 0x0000000E,
     0x0000000B, 0x00000008, 0x00000007, 0x00000004, 0x00000002, 0x00000001, 0x00000003,
     0x00000005, 0x00000006, 0x00000009, 0x0000000C, 0x0000000D, 0x0000000E, 0x0000000E,
     0x0000000E, 0x0000000E, 0x0000000E, 0x0000000E},

    /*v_huff_noise_lvl_c11t*/
    {0x00001FCE, 0x00001FCF, 0x00001FD0, 0x00001FD1, 0x00001FD2, 0x00001FD3,
     0x00001FD4, 0x00001FD5, 0x00001FD6, 0x00001FD7, 0x00001FD8, 0x00001FD9,
     0x00001FDA, 0x00001FDB, 0x00001FDC, 0x00001FDD, 0x00001FDE, 0x00001FDF,
     0x00001FE0, 0x00001FE1, 0x00001FE2, 0x00001FE3, 0x00001FE4, 0x00001FE5,
     0x00001FE6, 0x00001FE7, 0x000007F2, 0x000000FD, 0x0000003E, 0x0000000E,
     0x00000006, 0x00000000, 0x00000002, 0x0000001E, 0x000000FC, 0x000003F8,
     0x00001FCC, 0x00001FE8, 0x00001FE9, 0x00001FEA, 0x00001FEB, 0x00001FEC,
     0x00001FCD, 0x00001FED, 0x00001FEE, 0x00001FEF, 0x00001FF0, 0x00001FF1,
     0x00001FF2, 0x00001FF3, 0x00001FF4, 0x00001FF5, 0x00001FF6, 0x00001FF7,
     0x00001FF8, 0x00001FF9, 0x00001FFA, 0x00001FFB, 0x00001FFC, 0x00001FFD,
     0x00001FFE, 0x00003FFE, 0x00003FFF

    },

    /*v_huff_noise_lvl_l11t*/
    {0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000B, 0x00000008,
     0x00000006, 0x00000004, 0x00000003, 0x00000001, 0x00000002, 0x00000005, 0x00000008,
     0x0000000A, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D,
     0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000D, 0x0000000E, 0x0000000E},

    /*book_sbr_noise_bal_c11t*/
    {0x000000EC, 0x000000ED, 0x000000EE, 0x000000EF, 0x000000F0, 0x000000F1, 0x000000F2,
     0x000000F3, 0x000000F4, 0x000000F5, 0x0000001C, 0x00000002, 0x00000000, 0x00000006,
     0x0000003A, 0x000000F6, 0x000000F7, 0x000000F8, 0x000000F9, 0x000000FA, 0x000000FB,
     0x000000FC, 0x000000FD, 0x000000FE, 0x000000FF},

    /*book_sbr_noise_bal_l11t*/
    {0x00000008, 0x00000008, 0x00000008, 0x00000008, 0x00000008, 0x00000008, 0x00000008,
     0x00000008, 0x00000008, 0x00000008, 0x00000005, 0x00000002, 0x00000001, 0x00000003,
     0x00000006, 0x00000008, 0x00000008, 0x00000008, 0x00000008, 0x00000008, 0x00000008,
     0x00000008, 0x00000008, 0x00000008, 0x00000008}};

const ixheaace_str_esbr_sfb_bin_tabs ia_esbr_sfb_bin_tabs = {
    {24, 24, 24, 24, 24, 24, 28, 32, 32, 32, 40, 40, 48, 52, 60, 72, 84, 100, 116, 144, -1},
    {16, 16, 16, 16, 16, 20, 24,  24,  24,  24, 32, 32,
     40, 44, 52, 60, 76, 84, 100, 116, 128, 64, -1},
    {16, 16, 16, 16, 16, 20, 24,  24,  24,  24, 32, 32,
     40, 44, 52, 60, 76, 84, 100, 116, 128, 64, -1},
    {16, 16, 16, 16, 16, 20, 24,  24,  24,  24, 32, 32,
     40, 44, 52, 60, 76, 84, 100, 116, 128, 64, -1},
    {8,  8,  8,  8,  8,  12, 16, 16,  16,  16,  20, 24, 28,
     32, 40, 48, 56, 68, 76, 92, 104, 128, 128, 64, -1},
    {8,  8,  8,  8,  8,  12, 16, 16,  16,  16,  20, 24, 28,
     32, 40, 48, 56, 68, 76, 92, 104, 128, 128, 64, -1},
    {8,  8,  8,  8,  8,  16, 16, 16, 20, 24, 28, 36, 44, 52,
     60, 64, 64, 64, 64, 64, 64, 64, 64, 64, 64, 32, -1},
    {8,  8,  8,  8,  8,  16, 16, 16, 20, 24, 28, 36, 44,
     52, 60, 64, 64, 64, 64, 64, 64, 64, 64, 64, 96, -1},
    {8,  8,  8,  8,  8,  16, 16, 16, 20, 24, 28, 36, 44,
     52, 60, 64, 64, 64, 64, 64, 64, 64, 64, 64, 96, -1},
};

const WORD32 ixheaace_start_freq_16k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -8, -7, -6, -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7};

const WORD32 ixheaace_start_freq_22k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -5, -4, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13};

const WORD32 ixheaace_start_freq_24k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -5, -3, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16};

const WORD32 ixheaace_start_freq_32k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -6, -4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16};

const WORD32 ixheaace_start_freq_48k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -4, -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20};

const WORD32 ixheaace_start_freq_96k_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    -2, -1, 0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20, 24};

const WORD32 ixheaace_start_freq_dflt_4_1[SBR_START_FREQ_OFFSET_TBL_LEN] = {
    0, 1, 2, 3, 4, 5, 6, 7, 9, 11, 13, 16, 20, 24, 28, 33};

const WORD32 ixheaace_stop_freq_16k_4_1[SBR_STOP_FREQ_OFFSET_TBL_LEN] = {
    24, 26, 28, 30, 32, 35, 38, 41, 44, 47, 51, 55, 59, 64};

const WORD32 ixheaace_stop_freq_22k_4_1[SBR_STOP_FREQ_OFFSET_TBL_LEN] = {
    17, 19, 21, 23, 26, 28, 31, 35, 38, 43, 47, 52, 58, 64};

const WORD32 ixheaace_stop_freq_24k_4_1[SBR_STOP_FREQ_OFFSET_TBL_LEN] = {
    16, 18, 20, 22, 25, 27, 30, 34, 38, 42, 46, 52, 58, 64};

const WORD32 ixheaace_stop_freq_32k_4_1[SBR_STOP_FREQ_OFFSET_TBL_LEN] = {
    16, 18, 20, 22, 25, 27, 30, 34, 38, 42, 46, 52, 58, 64};

const WORD32 ixheaace_stop_freq_44k_4_1[SBR_STOP_FREQ_OFFSET_TBL_LEN] = {
    12, 14, 16, 18, 20, 23, 26, 30, 34, 38, 43, 49, 56, 64};

const WORD32 ixheaace_stop_freq_48k_4_1[14] = {11, 13, 14, 17, 19, 22, 25,
                                               28, 33, 37, 43, 49, 56, 64};

const WORD32 ixheaace_usac_stop_freq_16k[14] = {48, 49, 50, 51, 52, 54, 55, 56,
                                                57, 59, 60, 61, 63, 64 };

const WORD32 ixheaace_usac_stop_freq_22k[14] = {35, 37, 38, 40, 42, 44, 46,
                                                48, 51, 53, 56, 58, 61, 64 };

const WORD32 ixheaace_usac_stop_freq_24k[14] = {32, 34, 36, 38, 40, 42, 44,
                                                46, 49, 52, 55, 58, 61, 64 };

const WORD32 ixheaace_stop_freq_16k[14] = {64, 64, 64, 64, 64, 64, 64,
                                           64, 64, 64, 64, 64, 64, 64};

const WORD32 ixheaace_stop_freq_22k[14] = {46, 47, 48, 50, 51, 52, 54,
                                           55, 56, 58, 59, 61, 62, 64};

const WORD32 ixheaace_stop_freq_24k[14] = {43, 44, 46, 47, 49, 50, 52,
                                           53, 55, 57, 58, 60, 62, 64};

const WORD32 ixheaace_stop_freq_32k[14] = {32, 34, 36, 38, 40, 42, 44,
                                           46, 49, 52, 55, 58, 61, 64};

const WORD32 ixheaace_stop_freq_44k[14] = {23, 25, 27, 29, 32, 34, 37,
                                           40, 43, 47, 51, 55, 59, 64};

const WORD32 ixheaace_stop_freq_48k[14] = {21, 23, 25, 27, 30, 32, 35,
                                           38, 42, 45, 49, 54, 59, 64};
const ixheaace_str_qmf_dec_tabs_struct ixheaace_str_aac_qmf_tabs = {
    // w_16[2 * 12] =
    {0,     32767, 0,     32767, 0,     32767,  12540, 30274, 23170, 23170,  30274,  12540,
     23170, 23170, 32767, 0,     23170, -23170, 30274, 12540, 23170, -23170, -12540, -30274},

    // dig_rev_tab_4_16[2]=
    {0, 16},

    // FLOAT32 esbr_qmf_c[1280];
    {0.0000000000f,  -0.0002762643f, -0.0002808846f, -0.0002473758f, -0.0002437613f,
     -0.0002446894f, -0.0002520357f, -0.0002613282f, -0.0002733283f, -0.0002838899f,
     -0.0002935464f, -0.0003066373f, -0.0003156245f, -0.0003270165f, -0.0003388845f,
     -0.0003470806f, -0.0003578868f, -0.0003627520f, -0.0003720471f, -0.0003745297f,
     -0.0003840686f, -0.0003862423f, -0.0003917166f, -0.0003889934f, -0.0003901832f,
     -0.0003900724f, -0.0003878986f, -0.0003815396f, -0.0003765000f, -0.0003659676f,
     -0.0003607695f, -0.0003458967f, -0.0003325206f, -0.0003170797f, -0.0002973059f,
     -0.0002782287f, -0.0002572786f, -0.0002303161f, -0.0002047559f, -0.0001750586f,
     -0.0001448488f, -0.0001049167f, -0.0000723188f, -0.0000308666f, 0.0000067474f,
     0.0000547189f,  0.0001021507f,  0.0001474763f,  0.0002013268f,  0.0002553693f,
     0.0003119686f,  0.0003729011f,  0.0004304221f,  0.0004942992f,  0.0005625077f,
     0.0006288942f,  0.0006951247f,  0.0007721609f,  0.0008434041f,  0.0009174130f,
     0.0009920569f,  0.0010730790f,  0.0011508625f,  0.0012312806f,  0.0013100877f,
     0.0013935231f,  0.0014734722f,  0.0015562710f,  0.0016369806f,  0.0017209435f,
     0.0018004132f,  0.0018801959f,  0.0019603714f,  0.0020409876f,  0.0021132133f,
     0.0021865359f,  0.0022604924f,  0.0023303230f,  0.0023966280f,  0.0024568802f,
     0.0025196511f,  0.0025703677f,  0.0026230582f,  0.0026735840f,  0.0027098388f,
     0.0027438018f,  0.0027737855f,  0.0027969009f,  0.0028110321f,  0.0028227598f,
     0.0028194599f,  0.0028133057f,  0.0027958562f,  0.0027702181f,  0.0027376891f,
     0.0026919488f,  0.0026357877f,  0.0025691136f,  0.0024919843f,  0.0024054733f,
     0.0023019763f,  0.0021900930f,  0.0020625819f,  0.0019228202f,  0.0017700621f,
     0.0016045941f,  0.0014223377f,  0.0012254268f,  0.0010137088f,  0.0007892339f,
     0.0005451164f,  0.0002916132f,  0.0000138022f,  -0.0002732140f, -0.0005784067f,
     -0.0009019736f, -0.0012413361f, -0.0015966888f, -0.0019700560f, -0.0023611297f,
     -0.0027668604f, -0.0031896145f, -0.0036307906f, -0.0040899115f, -0.0045662662f,
     -0.0050575109f, -0.0055657774f, -0.0060924999f, 0.0066359108f,  0.0071952334f,
     0.0077702776f,  0.0083662355f,  0.0089716688f,  0.0095936209f,  0.0102265896f,
     0.0108733773f,  0.0115340082f,  0.0122080492f,  0.0128937922f,  0.0135929715f,
     0.0143036088f,  0.0150251333f,  0.0157508813f,  0.0164877046f,  0.0172310472f,
     0.0179848783f,  0.0187406428f,  0.0195026845f,  0.0202674586f,  0.0210324544f,
     0.0218048766f,  0.0225744210f,  0.0233421512f,  0.0241082851f,  0.0248692874f,
     0.0256278068f,  0.0263815373f,  0.0271226391f,  0.0278586820f,  0.0285808221f,
     0.0292957835f,  0.0299918745f,  0.0306727588f,  0.0313428901f,  0.0319857933f,
     0.0326123536f,  0.0332183763f,  0.0338037983f,  0.0343521908f,  0.0348815136f,
     0.0353814363f,  0.0358501337f,  0.0362841301f,  0.0366810113f,  0.0370501801f,
     0.0373726264f,  0.0376568660f,  0.0379004180f,  0.0380996242f,  0.0382496081f,
     0.0383546725f,  0.0384087004f,  0.0384115018f,  0.0383602455f,  0.0382525362f,
     0.0380874164f,  0.0378652886f,  0.0375788137f,  0.0372332186f,  0.0368202999f,
     0.0363387316f,  0.0357913189f,  0.0351766534f,  0.0344832018f,  0.0337262526f,
     0.0328845344f,  0.0319722407f,  0.0309801381f,  0.0299083292f,  0.0287576355f,
     0.0275230017f,  0.0262046903f,  0.0247989334f,  0.0233151652f,  0.0217384398f,
     0.0200729147f,  0.0183209050f,  0.0164791960f,  0.0145412004f,  0.0125153782f,
     0.0103998538f,  0.0081850626f,  0.0058811912f,  0.0034818430f,  0.0009882799f,
     -0.0016043447f, -0.0042855870f, -0.0070644412f, -0.0099417064f, -0.0129113644f,
     -0.0159765631f, -0.0191388279f, -0.0223903414f, -0.0257402081f, -0.0291852653f,
     -0.0327204913f, -0.0363471657f, -0.0400686450f, -0.0438773781f, -0.0477766693f,
     -0.0517664775f, -0.0558413453f, -0.0600038990f, -0.0642501414f, -0.0685775876f,
     -0.0729883239f, -0.0774803534f, -0.0820479393f, -0.0866904110f, -0.0914086252f,
     -0.0961983353f, -0.1010625064f, -0.1059867889f, -0.1109826341f, -0.1160345450f,
     -0.1211508438f, -0.1263240129f, -0.1315526664f, -0.1368317008f, -0.1421607137f,
     -0.1475358307f, -0.1529549360f, -0.1584139466f, -0.1639056802f, -0.1694361269f,
     -0.1749957055f, 0.1805794984f,  0.1861897707f,  0.1918175071f,  0.1974605918f,
     0.2031158805f,  0.2087848485f,  0.2144559920f,  0.2201276869f,  0.2257998288f,
     0.2314653993f,  0.2371226549f,  0.2427626550f,  0.2483854145f,  0.2539908886f,
     0.2595617473f,  0.2651120424f,  0.2706276774f,  0.2761025727f,  0.2815394700f,
     0.2869262099f,  0.2922701538f,  0.2975561619f,  0.3027891815f,  0.3079555035f,
     0.3130621314f,  0.3180989921f,  0.3230634928f,  0.3279508054f,  0.3327569962f,
     0.3374831676f,  0.3421176672f,  0.3466641307f,  0.3511194289f,  0.3554705083f,
     0.3597231209f,  0.3638724387f,  0.3679105937f,  0.3718414009f,  0.3756568730f,
     0.3793540299f,  0.3829337358f,  0.3863890469f,  0.3897143900f,  0.3929176629f,
     0.3959867954f,  0.3989233077f,  0.4017242789f,  0.4043847620f,  0.4069095552f,
     0.4092887938f,  0.4115209877f,  0.4136137664f,  0.4155519307f,  0.4173468649f,
     0.4189858735f,  0.4204770625f,  0.4218119085f,  0.4229909182f,  0.4240157902f,
     0.4248902500f,  0.4255985618f,  0.4261523485f,  0.4265510440f,  0.4267860353f,
     0.4268692732f,  0.4267860353f,  0.4265510440f,  0.4261523485f,  0.4255985618f,
     0.4248902500f,  0.4240157902f,  0.4229909182f,  0.4218119085f,  0.4204770625f,
     0.4189858735f,  0.4173468649f,  0.4155519307f,  0.4136137664f,  0.4115209877f,
     0.4092887938f,  0.4069095552f,  0.4043847620f,  0.4017242789f,  0.3989233077f,
     0.3959867954f,  0.3929176629f,  0.3897143900f,  0.3863890469f,  0.3829337358f,
     0.3793540299f,  0.3756568730f,  0.3718414009f,  0.3679105937f,  0.3638724387f,
     0.3597231209f,  0.3554705083f,  0.3511194289f,  0.3466641307f,  0.3421176672f,
     0.3374831676f,  0.3327569962f,  0.3279508054f,  0.3230634928f,  0.3180989921f,
     0.3130621314f,  0.3079555035f,  0.3027891815f,  0.2975561619f,  0.2922701538f,
     0.2869262099f,  0.2815394700f,  0.2761025727f,  0.2706276774f,  0.2651120424f,
     0.2595617473f,  0.2539908886f,  0.2483854145f,  0.2427626550f,  0.2371226549f,
     0.2314653993f,  0.2257998288f,  0.2201276869f,  0.2144559920f,  0.2087848485f,
     0.2031158805f,  0.1974605918f,  0.1918175071f,  0.1861897707f,  -0.1805794984f,
     -0.1749957055f, -0.1694361269f, -0.1639056802f, -0.1584139466f, -0.1529549360f,
     -0.1475358307f, -0.1421607137f, -0.1368317008f, -0.1315526664f, -0.1263240129f,
     -0.1211508438f, -0.1160345450f, -0.1109826341f, -0.1059867889f, -0.1010625064f,
     -0.0961983353f, -0.0914086252f, -0.0866904110f, -0.0820479393f, -0.0774803534f,
     -0.0729883239f, -0.0685775876f, -0.0642501414f, -0.0600038990f, -0.0558413453f,
     -0.0517664775f, -0.0477766693f, -0.0438773781f, -0.0400686450f, -0.0363471657f,
     -0.0327204913f, -0.0291852653f, -0.0257402081f, -0.0223903414f, -0.0191388279f,
     -0.0159765631f, -0.0129113644f, -0.0099417064f, -0.0070644412f, -0.0042855870f,
     -0.0016043447f, 0.0009882799f,  0.0034818430f,  0.0058811912f,  0.0081850626f,
     0.0103998538f,  0.0125153782f,  0.0145412004f,  0.0164791960f,  0.0183209050f,
     0.0200729147f,  0.0217384398f,  0.0233151652f,  0.0247989334f,  0.0262046903f,
     0.0275230017f,  0.0287576355f,  0.0299083292f,  0.0309801381f,  0.0319722407f,
     0.0328845344f,  0.0337262526f,  0.0344832018f,  0.0351766534f,  0.0357913189f,
     0.0363387316f,  0.0368202999f,  0.0372332186f,  0.0375788137f,  0.0378652886f,
     0.0380874164f,  0.0382525362f,  0.0383602455f,  0.0384115018f,  0.0384087004f,
     0.0383546725f,  0.0382496081f,  0.0380996242f,  0.0379004180f,  0.0376568660f,
     0.0373726264f,  0.0370501801f,  0.0366810113f,  0.0362841301f,  0.0358501337f,
     0.0353814363f,  0.0348815136f,  0.0343521908f,  0.0338037983f,  0.0332183763f,
     0.0326123536f,  0.0319857933f,  0.0313428901f,  0.0306727588f,  0.0299918745f,
     0.0292957835f,  0.0285808221f,  0.0278586820f,  0.0271226391f,  0.0263815373f,
     0.0256278068f,  0.0248692874f,  0.0241082851f,  0.0233421512f,  0.0225744210f,
     0.0218048766f,  0.0210324544f,  0.0202674586f,  0.0195026845f,  0.0187406428f,
     0.0179848783f,  0.0172310472f,  0.0164877046f,  0.0157508813f,  0.0150251333f,
     0.0143036088f,  0.0135929715f,  0.0128937922f,  0.0122080492f,  0.0115340082f,
     0.0108733773f,  0.0102265896f,  0.0095936209f,  0.0089716688f,  0.0083662355f,
     0.0077702776f,  0.0071952334f,  -0.0066359108f, -0.0060924999f, -0.0055657774f,
     -0.0050575109f, -0.0045662662f, -0.0040899115f, -0.0036307906f, -0.0031896145f,
     -0.0027668604f, -0.0023611297f, -0.0019700560f, -0.0015966888f, -0.0012413361f,
     -0.0009019736f, -0.0005784067f, -0.0002732140f, 0.0000138022f,  0.0002916132f,
     0.0005451164f,  0.0007892339f,  0.0010137088f,  0.0012254268f,  0.0014223377f,
     0.0016045941f,  0.0017700621f,  0.0019228202f,  0.0020625819f,  0.0021900930f,
     0.0023019763f,  0.0024054733f,  0.0024919843f,  0.0025691136f,  0.0026357877f,
     0.0026919488f,  0.0027376891f,  0.0027702181f,  0.0027958562f,  0.0028133057f,
     0.0028194599f,  0.0028227598f,  0.0028110321f,  0.0027969009f,  0.0027737855f,
     0.0027438018f,  0.0027098388f,  0.0026735840f,  0.0026230582f,  0.0025703677f,
     0.0025196511f,  0.0024568802f,  0.0023966280f,  0.0023303230f,  0.0022604924f,
     0.0021865359f,  0.0021132133f,  0.0020409876f,  0.0019603714f,  0.0018801959f,
     0.0018004132f,  0.0017209435f,  0.0016369806f,  0.0015562710f,  0.0014734722f,
     0.0013935231f,  0.0013100877f,  0.0012312806f,  0.0011508625f,  0.0010730790f,
     0.0009920569f,  0.0009174130f,  0.0008434041f,  0.0007721609f,  0.0006951247f,
     0.0006288942f,  0.0005625077f,  0.0004942992f,  0.0004304221f,  0.0003729011f,
     0.0003119686f,  0.0002553693f,  0.0002013268f,  0.0001474763f,  0.0001021507f,
     0.0000547189f,  0.0000067474f,  -0.0000308666f, -0.0000723188f, -0.0001049167f,
     -0.0001448488f, -0.0001750586f, -0.0002047559f, -0.0002303161f, -0.0002572786f,
     -0.0002782287f, -0.0002973059f, -0.0003170797f, -0.0003325206f, -0.0003458967f,
     -0.0003607695f, -0.0003659676f, -0.0003765000f, -0.0003815396f, -0.0003878986f,
     -0.0003900724f, -0.0003901832f, -0.0003889934f, -0.0003917166f, -0.0003862423f,
     -0.0003840686f, -0.0003745297f, -0.0003720471f, -0.0003627520f, -0.0003578868f,
     -0.0003470806f, -0.0003388845f, -0.0003270165f, -0.0003156245f, -0.0003066373f,
     -0.0002935464f, -0.0002838899f, -0.0002733283f, -0.0002613282f, -0.0002520357f,
     -0.0002446894f, -0.0002437613f, -0.0002473758f, -0.0002808846f, -0.0002762643f,
     0.0000000000f,  -0.0002762643f, -0.0002808846f, -0.0002473758f, -0.0002437613f,
     -0.0002446894f, -0.0002520357f, -0.0002613282f, -0.0002733283f, -0.0002838899f,
     -0.0002935464f, -0.0003066373f, -0.0003156245f, -0.0003270165f, -0.0003388845f,
     -0.0003470806f, -0.0003578868f, -0.0003627520f, -0.0003720471f, -0.0003745297f,
     -0.0003840686f, -0.0003862423f, -0.0003917166f, -0.0003889934f, -0.0003901832f,
     -0.0003900724f, -0.0003878986f, -0.0003815396f, -0.0003765000f, -0.0003659676f,
     -0.0003607695f, -0.0003458967f, -0.0003325206f, -0.0003170797f, -0.0002973059f,
     -0.0002782287f, -0.0002572786f, -0.0002303161f, -0.0002047559f, -0.0001750586f,
     -0.0001448488f, -0.0001049167f, -0.0000723188f, -0.0000308666f, 0.0000067474f,
     0.0000547189f,  0.0001021507f,  0.0001474763f,  0.0002013268f,  0.0002553693f,
     0.0003119686f,  0.0003729011f,  0.0004304221f,  0.0004942992f,  0.0005625077f,
     0.0006288942f,  0.0006951247f,  0.0007721609f,  0.0008434041f,  0.0009174130f,
     0.0009920569f,  0.0010730790f,  0.0011508625f,  0.0012312806f,  0.0013100877f,
     0.0013935231f,  0.0014734722f,  0.0015562710f,  0.0016369806f,  0.0017209435f,
     0.0018004132f,  0.0018801959f,  0.0019603714f,  0.0020409876f,  0.0021132133f,
     0.0021865359f,  0.0022604924f,  0.0023303230f,  0.0023966280f,  0.0024568802f,
     0.0025196511f,  0.0025703677f,  0.0026230582f,  0.0026735840f,  0.0027098388f,
     0.0027438018f,  0.0027737855f,  0.0027969009f,  0.0028110321f,  0.0028227598f,
     0.0028194599f,  0.0028133057f,  0.0027958562f,  0.0027702181f,  0.0027376891f,
     0.0026919488f,  0.0026357877f,  0.0025691136f,  0.0024919843f,  0.0024054733f,
     0.0023019763f,  0.0021900930f,  0.0020625819f,  0.0019228202f,  0.0017700621f,
     0.0016045941f,  0.0014223377f,  0.0012254268f,  0.0010137088f,  0.0007892339f,
     0.0005451164f,  0.0002916132f,  0.0000138022f,  -0.0002732140f, -0.0005784067f,
     -0.0009019736f, -0.0012413361f, -0.0015966888f, -0.0019700560f, -0.0023611297f,
     -0.0027668604f, -0.0031896145f, -0.0036307906f, -0.0040899115f, -0.0045662662f,
     -0.0050575109f, -0.0055657774f, -0.0060924999f, 0.0066359108f,  0.0071952334f,
     0.0077702776f,  0.0083662355f,  0.0089716688f,  0.0095936209f,  0.0102265896f,
     0.0108733773f,  0.0115340082f,  0.0122080492f,  0.0128937922f,  0.0135929715f,
     0.0143036088f,  0.0150251333f,  0.0157508813f,  0.0164877046f,  0.0172310472f,
     0.0179848783f,  0.0187406428f,  0.0195026845f,  0.0202674586f,  0.0210324544f,
     0.0218048766f,  0.0225744210f,  0.0233421512f,  0.0241082851f,  0.0248692874f,
     0.0256278068f,  0.0263815373f,  0.0271226391f,  0.0278586820f,  0.0285808221f,
     0.0292957835f,  0.0299918745f,  0.0306727588f,  0.0313428901f,  0.0319857933f,
     0.0326123536f,  0.0332183763f,  0.0338037983f,  0.0343521908f,  0.0348815136f,
     0.0353814363f,  0.0358501337f,  0.0362841301f,  0.0366810113f,  0.0370501801f,
     0.0373726264f,  0.0376568660f,  0.0379004180f,  0.0380996242f,  0.0382496081f,
     0.0383546725f,  0.0384087004f,  0.0384115018f,  0.0383602455f,  0.0382525362f,
     0.0380874164f,  0.0378652886f,  0.0375788137f,  0.0372332186f,  0.0368202999f,
     0.0363387316f,  0.0357913189f,  0.0351766534f,  0.0344832018f,  0.0337262526f,
     0.0328845344f,  0.0319722407f,  0.0309801381f,  0.0299083292f,  0.0287576355f,
     0.0275230017f,  0.0262046903f,  0.0247989334f,  0.0233151652f,  0.0217384398f,
     0.0200729147f,  0.0183209050f,  0.0164791960f,  0.0145412004f,  0.0125153782f,
     0.0103998538f,  0.0081850626f,  0.0058811912f,  0.0034818430f,  0.0009882799f,
     -0.0016043447f, -0.0042855870f, -0.0070644412f, -0.0099417064f, -0.0129113644f,
     -0.0159765631f, -0.0191388279f, -0.0223903414f, -0.0257402081f, -0.0291852653f,
     -0.0327204913f, -0.0363471657f, -0.0400686450f, -0.0438773781f, -0.0477766693f,
     -0.0517664775f, -0.0558413453f, -0.0600038990f, -0.0642501414f, -0.0685775876f,
     -0.0729883239f, -0.0774803534f, -0.0820479393f, -0.0866904110f, -0.0914086252f,
     -0.0961983353f, -0.1010625064f, -0.1059867889f, -0.1109826341f, -0.1160345450f,
     -0.1211508438f, -0.1263240129f, -0.1315526664f, -0.1368317008f, -0.1421607137f,
     -0.1475358307f, -0.1529549360f, -0.1584139466f, -0.1639056802f, -0.1694361269f,
     -0.1749957055f, 0.1805794984f,  0.1861897707f,  0.1918175071f,  0.1974605918f,
     0.2031158805f,  0.2087848485f,  0.2144559920f,  0.2201276869f,  0.2257998288f,
     0.2314653993f,  0.2371226549f,  0.2427626550f,  0.2483854145f,  0.2539908886f,
     0.2595617473f,  0.2651120424f,  0.2706276774f,  0.2761025727f,  0.2815394700f,
     0.2869262099f,  0.2922701538f,  0.2975561619f,  0.3027891815f,  0.3079555035f,
     0.3130621314f,  0.3180989921f,  0.3230634928f,  0.3279508054f,  0.3327569962f,
     0.3374831676f,  0.3421176672f,  0.3466641307f,  0.3511194289f,  0.3554705083f,
     0.3597231209f,  0.3638724387f,  0.3679105937f,  0.3718414009f,  0.3756568730f,
     0.3793540299f,  0.3829337358f,  0.3863890469f,  0.3897143900f,  0.3929176629f,
     0.3959867954f,  0.3989233077f,  0.4017242789f,  0.4043847620f,  0.4069095552f,
     0.4092887938f,  0.4115209877f,  0.4136137664f,  0.4155519307f,  0.4173468649f,
     0.4189858735f,  0.4204770625f,  0.4218119085f,  0.4229909182f,  0.4240157902f,
     0.4248902500f,  0.4255985618f,  0.4261523485f,  0.4265510440f,  0.4267860353f,
     0.4268692732f,  0.4267860353f,  0.4265510440f,  0.4261523485f,  0.4255985618f,
     0.4248902500f,  0.4240157902f,  0.4229909182f,  0.4218119085f,  0.4204770625f,
     0.4189858735f,  0.4173468649f,  0.4155519307f,  0.4136137664f,  0.4115209877f,
     0.4092887938f,  0.4069095552f,  0.4043847620f,  0.4017242789f,  0.3989233077f,
     0.3959867954f,  0.3929176629f,  0.3897143900f,  0.3863890469f,  0.3829337358f,
     0.3793540299f,  0.3756568730f,  0.3718414009f,  0.3679105937f,  0.3638724387f,
     0.3597231209f,  0.3554705083f,  0.3511194289f,  0.3466641307f,  0.3421176672f,
     0.3374831676f,  0.3327569962f,  0.3279508054f,  0.3230634928f,  0.3180989921f,
     0.3130621314f,  0.3079555035f,  0.3027891815f,  0.2975561619f,  0.2922701538f,
     0.2869262099f,  0.2815394700f,  0.2761025727f,  0.2706276774f,  0.2651120424f,
     0.2595617473f,  0.2539908886f,  0.2483854145f,  0.2427626550f,  0.2371226549f,
     0.2314653993f,  0.2257998288f,  0.2201276869f,  0.2144559920f,  0.2087848485f,
     0.2031158805f,  0.1974605918f,  0.1918175071f,  0.1861897707f,  -0.1805794984f,
     -0.1749957055f, -0.1694361269f, -0.1639056802f, -0.1584139466f, -0.1529549360f,
     -0.1475358307f, -0.1421607137f, -0.1368317008f, -0.1315526664f, -0.1263240129f,
     -0.1211508438f, -0.1160345450f, -0.1109826341f, -0.1059867889f, -0.1010625064f,
     -0.0961983353f, -0.0914086252f, -0.0866904110f, -0.0820479393f, -0.0774803534f,
     -0.0729883239f, -0.0685775876f, -0.0642501414f, -0.0600038990f, -0.0558413453f,
     -0.0517664775f, -0.0477766693f, -0.0438773781f, -0.0400686450f, -0.0363471657f,
     -0.0327204913f, -0.0291852653f, -0.0257402081f, -0.0223903414f, -0.0191388279f,
     -0.0159765631f, -0.0129113644f, -0.0099417064f, -0.0070644412f, -0.0042855870f,
     -0.0016043447f, 0.0009882799f,  0.0034818430f,  0.0058811912f,  0.0081850626f,
     0.0103998538f,  0.0125153782f,  0.0145412004f,  0.0164791960f,  0.0183209050f,
     0.0200729147f,  0.0217384398f,  0.0233151652f,  0.0247989334f,  0.0262046903f,
     0.0275230017f,  0.0287576355f,  0.0299083292f,  0.0309801381f,  0.0319722407f,
     0.0328845344f,  0.0337262526f,  0.0344832018f,  0.0351766534f,  0.0357913189f,
     0.0363387316f,  0.0368202999f,  0.0372332186f,  0.0375788137f,  0.0378652886f,
     0.0380874164f,  0.0382525362f,  0.0383602455f,  0.0384115018f,  0.0384087004f,
     0.0383546725f,  0.0382496081f,  0.0380996242f,  0.0379004180f,  0.0376568660f,
     0.0373726264f,  0.0370501801f,  0.0366810113f,  0.0362841301f,  0.0358501337f,
     0.0353814363f,  0.0348815136f,  0.0343521908f,  0.0338037983f,  0.0332183763f,
     0.0326123536f,  0.0319857933f,  0.0313428901f,  0.0306727588f,  0.0299918745f,
     0.0292957835f,  0.0285808221f,  0.0278586820f,  0.0271226391f,  0.0263815373f,
     0.0256278068f,  0.0248692874f,  0.0241082851f,  0.0233421512f,  0.0225744210f,
     0.0218048766f,  0.0210324544f,  0.0202674586f,  0.0195026845f,  0.0187406428f,
     0.0179848783f,  0.0172310472f,  0.0164877046f,  0.0157508813f,  0.0150251333f,
     0.0143036088f,  0.0135929715f,  0.0128937922f,  0.0122080492f,  0.0115340082f,
     0.0108733773f,  0.0102265896f,  0.0095936209f,  0.0089716688f,  0.0083662355f,
     0.0077702776f,  0.0071952334f,  -0.0066359108f, -0.0060924999f, -0.0055657774f,
     -0.0050575109f, -0.0045662662f, -0.0040899115f, -0.0036307906f, -0.0031896145f,
     -0.0027668604f, -0.0023611297f, -0.0019700560f, -0.0015966888f, -0.0012413361f,
     -0.0009019736f, -0.0005784067f, -0.0002732140f, 0.0000138022f,  0.0002916132f,
     0.0005451164f,  0.0007892339f,  0.0010137088f,  0.0012254268f,  0.0014223377f,
     0.0016045941f,  0.0017700621f,  0.0019228202f,  0.0020625819f,  0.0021900930f,
     0.0023019763f,  0.0024054733f,  0.0024919843f,  0.0025691136f,  0.0026357877f,
     0.0026919488f,  0.0027376891f,  0.0027702181f,  0.0027958562f,  0.0028133057f,
     0.0028194599f,  0.0028227598f,  0.0028110321f,  0.0027969009f,  0.0027737855f,
     0.0027438018f,  0.0027098388f,  0.0026735840f,  0.0026230582f,  0.0025703677f,
     0.0025196511f,  0.0024568802f,  0.0023966280f,  0.0023303230f,  0.0022604924f,
     0.0021865359f,  0.0021132133f,  0.0020409876f,  0.0019603714f,  0.0018801959f,
     0.0018004132f,  0.0017209435f,  0.0016369806f,  0.0015562710f,  0.0014734722f,
     0.0013935231f,  0.0013100877f,  0.0012312806f,  0.0011508625f,  0.0010730790f,
     0.0009920569f,  0.0009174130f,  0.0008434041f,  0.0007721609f,  0.0006951247f,
     0.0006288942f,  0.0005625077f,  0.0004942992f,  0.0004304221f,  0.0003729011f,
     0.0003119686f,  0.0002553693f,  0.0002013268f,  0.0001474763f,  0.0001021507f,
     0.0000547189f,  0.0000067474f,  -0.0000308666f, -0.0000723188f, -0.0001049167f,
     -0.0001448488f, -0.0001750586f, -0.0002047559f, -0.0002303161f, -0.0002572786f,
     -0.0002782287f, -0.0002973059f, -0.0003170797f, -0.0003325206f, -0.0003458967f,
     -0.0003607695f, -0.0003659676f, -0.0003765000f, -0.0003815396f, -0.0003878986f,
     -0.0003900724f, -0.0003901832f, -0.0003889934f, -0.0003917166f, -0.0003862423f,
     -0.0003840686f, -0.0003745297f, -0.0003720471f, -0.0003627520f, -0.0003578868f,
     -0.0003470806f, -0.0003388845f, -0.0003270165f, -0.0003156245f, -0.0003066373f,
     -0.0002935464f, -0.0002838899f, -0.0002733283f, -0.0002613282f, -0.0002520357f,
     -0.0002446894f, -0.0002437613f, -0.0002473758f, -0.0002808846f, -0.0002762643f},
    {0.0000000000f,  -0.0002585454f, -0.0002471381f, -0.0002733283f, -0.0003022735f,
     -0.0003309725f, -0.0003578868f, -0.0003737023f, -0.0003880670f, -0.0003901832f,
     -0.0003836593f, -0.0003642349f, -0.0003325206f, -0.0002845877f, -0.0002217961f,
     -0.0001448488f, -0.0000446842f, 0.0000705295f,  0.0002013268f,  0.0003525903f,
     0.0005170354f,  0.0006951247f,  0.0008927435f,  0.0010990070f,  0.0013100877f,
     0.0015286715f,  0.0017474336f,  0.0019603714f,  0.0021620949f,  0.0023524247f,
     0.0025196511f,  0.0026567420f,  0.0027537965f,  0.0028110321f,  0.0028153569f,
     0.0027593751f,  0.0026357877f,  0.0024343103f,  0.0021475893f,  0.0017700621f,
     0.0012910638f,  0.0007078615f,  0.0000138022f,  -0.0007941178f, -0.0017211447f,
     -0.0027668604f, -0.0039368710f, -0.0052269329f, 0.0066359108f,  0.0081675826f,
     0.0098046111f,  0.0115340082f,  0.0133599117f,  0.0152670480f,  0.0172310472f,
     0.0192486700f,  0.0212899297f,  0.0233421512f,  0.0253749676f,  0.0273679867f,
     0.0292957835f,  0.0311195124f,  0.0328143612f,  0.0343521908f,  0.0356939025f,
     0.0368040688f,  0.0376568660f,  0.0381996147f,  0.0384096317f,  0.0382525362f,
     0.0376743041f,  0.0366597772f,  0.0351766534f,  0.0331651047f,  0.0306228697f,
     0.0275230017f,  0.0238097552f,  0.0194889121f,  0.0145412004f,  0.0089233266f,
     0.0026506553f,  -0.0042855870f, -0.0119214784f, -0.0202226657f, -0.0291852653f,
     -0.0388281532f, -0.0491066054f, -0.0600038990f, -0.0715180784f, -0.0835954323f,
     -0.0961983353f, -0.1093173549f, -0.1228752360f, -0.1368317008f, -0.1511485577f,
     -0.1657491624f, 0.1805794984f,  0.1955795586f,  0.2106752247f,  0.2257998288f,
     0.2408826500f,  0.2558478415f,  0.2706276774f,  0.2851306200f,  0.2993004918f,
     0.3130621314f,  0.3263216913f,  0.3390280008f,  0.3511194289f,  0.3624893427f,
     0.3731132150f,  0.3829337358f,  0.3918499053f,  0.3998569846f,  0.4069095552f,
     0.4129161835f,  0.4178932011f,  0.4218119085f,  0.4245987833f,  0.4262852371f,
     0.4268692732f,  0.4262852371f,  0.4245987833f,  0.4218119085f,  0.4178932011f,
     0.4129161835f,  0.4069095552f,  0.3998569846f,  0.3918499053f,  0.3829337358f,
     0.3731132150f,  0.3624893427f,  0.3511194289f,  0.3390280008f,  0.3263216913f,
     0.3130621314f,  0.2993004918f,  0.2851306200f,  0.2706276774f,  0.2558478415f,
     0.2408826500f,  0.2257998288f,  0.2106752247f,  0.1955795586f,  -0.1805794984f,
     -0.1657491624f, -0.1511485577f, -0.1368317008f, -0.1228752360f, -0.1093173549f,
     -0.0961983353f, -0.0835954323f, -0.0715180784f, -0.0600038990f, -0.0491066054f,
     -0.0388281532f, -0.0291852653f, -0.0202226657f, -0.0119214784f, -0.0042855870f,
     0.0026506553f,  0.0089233266f,  0.0145412004f,  0.0194889121f,  0.0238097552f,
     0.0275230017f,  0.0306228697f,  0.0331651047f,  0.0351766534f,  0.0366597772f,
     0.0376743041f,  0.0382525362f,  0.0384096317f,  0.0381996147f,  0.0376568660f,
     0.0368040688f,  0.0356939025f,  0.0343521908f,  0.0328143612f,  0.0311195124f,
     0.0292957835f,  0.0273679867f,  0.0253749676f,  0.0233421512f,  0.0212899297f,
     0.0192486700f,  0.0172310472f,  0.0152670480f,  0.0133599117f,  0.0115340082f,
     0.0098046111f,  0.0081675826f,  -0.0066359108f, -0.0052269329f, -0.0039368710f,
     -0.0027668604f, -0.0017211447f, -0.0007941178f, 0.0000138022f,  0.0007078615f,
     0.0012910638f,  0.0017700621f,  0.0021475893f,  0.0024343103f,  0.0026357877f,
     0.0027593751f,  0.0028153569f,  0.0028110321f,  0.0027537965f,  0.0026567420f,
     0.0025196511f,  0.0023524247f,  0.0021620949f,  0.0019603714f,  0.0017474336f,
     0.0015286715f,  0.0013100877f,  0.0010990070f,  0.0008927435f,  0.0006951247f,
     0.0005170354f,  0.0003525903f,  0.0002013268f,  0.0000705295f,  -0.0000446842f,
     -0.0001448488f, -0.0002217961f, -0.0002845877f, -0.0003325206f, -0.0003642349f,
     -0.0003836593f, -0.0003901832f, -0.0003880670f, -0.0003737023f, -0.0003578868f,
     -0.0003309725f, -0.0003022735f, -0.0002733283f, -0.0002471381f, -0.0002585454f,
     0.0000000000f,  -0.0002585454f, -0.0002471381f, -0.0002733283f, -0.0003022735f,
     -0.0003309725f, -0.0003578868f, -0.0003737023f, -0.0003880670f, -0.0003901832f,
     -0.0003836593f, -0.0003642349f, -0.0003325206f, -0.0002845877f, -0.0002217961f,
     -0.0001448488f, -0.0000446842f, 0.0000705295f,  0.0002013268f,  0.0003525903f,
     0.0005170354f,  0.0006951247f,  0.0008927435f,  0.0010990070f,  0.0013100877f,
     0.0015286715f,  0.0017474336f,  0.0019603714f,  0.0021620949f,  0.0023524247f,
     0.0025196511f,  0.0026567420f,  0.0027537965f,  0.0028110321f,  0.0028153569f,
     0.0027593751f,  0.0026357877f,  0.0024343103f,  0.0021475893f,  0.0017700621f,
     0.0012910638f,  0.0007078615f,  0.0000138022f,  -0.0007941178f, -0.0017211447f,
     -0.0027668604f, -0.0039368710f, -0.0052269329f, 0.0066359108f,  0.0081675826f,
     0.0098046111f,  0.0115340082f,  0.0133599117f,  0.0152670480f,  0.0172310472f,
     0.0192486700f,  0.0212899297f,  0.0233421512f,  0.0253749676f,  0.0273679867f,
     0.0292957835f,  0.0311195124f,  0.0328143612f,  0.0343521908f,  0.0356939025f,
     0.0368040688f,  0.0376568660f,  0.0381996147f,  0.0384096317f,  0.0382525362f,
     0.0376743041f,  0.0366597772f,  0.0351766534f,  0.0331651047f,  0.0306228697f,
     0.0275230017f,  0.0238097552f,  0.0194889121f,  0.0145412004f,  0.0089233266f,
     0.0026506553f,  -0.0042855870f, -0.0119214784f, -0.0202226657f, -0.0291852653f,
     -0.0388281532f, -0.0491066054f, -0.0600038990f, -0.0715180784f, -0.0835954323f,
     -0.0961983353f, -0.1093173549f, -0.1228752360f, -0.1368317008f, -0.1511485577f,
     -0.1657491624f, 0.1805794984f,  0.1955795586f,  0.2106752247f,  0.2257998288f,
     0.2408826500f,  0.2558478415f,  0.2706276774f,  0.2851306200f,  0.2993004918f,
     0.3130621314f,  0.3263216913f,  0.3390280008f,  0.3511194289f,  0.3624893427f,
     0.3731132150f,  0.3829337358f,  0.3918499053f,  0.3998569846f,  0.4069095552f,
     0.4129161835f,  0.4178932011f,  0.4218119085f,  0.4245987833f,  0.4262852371f,
     0.4268692732f,  0.4262852371f,  0.4245987833f,  0.4218119085f,  0.4178932011f,
     0.4129161835f,  0.4069095552f,  0.3998569846f,  0.3918499053f,  0.3829337358f,
     0.3731132150f,  0.3624893427f,  0.3511194289f,  0.3390280008f,  0.3263216913f,
     0.3130621314f,  0.2993004918f,  0.2851306200f,  0.2706276774f,  0.2558478415f,
     0.2408826500f,  0.2257998288f,  0.2106752247f,  0.1955795586f,  -0.1805794984f,
     -0.1657491624f, -0.1511485577f, -0.1368317008f, -0.1228752360f, -0.1093173549f,
     -0.0961983353f, -0.0835954323f, -0.0715180784f, -0.0600038990f, -0.0491066054f,
     -0.0388281532f, -0.0291852653f, -0.0202226657f, -0.0119214784f, -0.0042855870f,
     0.0026506553f,  0.0089233266f,  0.0145412004f,  0.0194889121f,  0.0238097552f,
     0.0275230017f,  0.0306228697f,  0.0331651047f,  0.0351766534f,  0.0366597772f,
     0.0376743041f,  0.0382525362f,  0.0384096317f,  0.0381996147f,  0.0376568660f,
     0.0368040688f,  0.0356939025f,  0.0343521908f,  0.0328143612f,  0.0311195124f,
     0.0292957835f,  0.0273679867f,  0.0253749676f,  0.0233421512f,  0.0212899297f,
     0.0192486700f,  0.0172310472f,  0.0152670480f,  0.0133599117f,  0.0115340082f,
     0.0098046111f,  0.0081675826f,  -0.0066359108f, -0.0052269329f, -0.0039368710f,
     -0.0027668604f, -0.0017211447f, -0.0007941178f, 0.0000138022f,  0.0007078615f,
     0.0012910638f,  0.0017700621f,  0.0021475893f,  0.0024343103f,  0.0026357877f,
     0.0027593751f,  0.0028153569f,  0.0028110321f,  0.0027537965f,  0.0026567420f,
     0.0025196511f,  0.0023524247f,  0.0021620949f,  0.0019603714f,  0.0017474336f,
     0.0015286715f,  0.0013100877f,  0.0010990070f,  0.0008927435f,  0.0006951247f,
     0.0005170354f,  0.0003525903f,  0.0002013268f,  0.0000705295f,  -0.0000446842f,
     -0.0001448488f, -0.0002217961f, -0.0002845877f, -0.0003325206f, -0.0003642349f,
     -0.0003836593f, -0.0003901832f, -0.0003880670f, -0.0003737023f, -0.0003578868f,
     -0.0003309725f, -0.0003022735f, -0.0002733283f, -0.0002471381f, -0.0002585454f},

    // const FLOAT32 esbr_w_16[2 * 12] =
    {0.0000000000f, 0.5000000000f, 0.0000000000f, 0.5000000000f,  0.0000000000f,  0.5000000000f,
     0.1913417131f, 0.4619397521f, 0.3535533845f, 0.3535533845f,  0.4619397521f,  0.1913417131f,
     0.3535533845f, 0.3535533845f, 0.5000000000f, 0.0000000000f,  0.3535533845f,  -0.3535533845f,
     0.4619397521f, 0.1913417131f, 0.3535533845f, -0.3535533845f, -0.1913417131f, -0.4619397521f},
    {
        // FLOAT32 esbr_sin_cos_twiddle_l64[64] =
        0.0061357692f, 0.4999623597f, 0.4996611774f, 0.0184036121f, 0.0306603685f, 0.4990590513f,
        0.4981563091f, 0.0428986549f, 0.0551111028f, 0.4969534874f, 0.4954513311f, 0.0672903508f,
        0.0794290751f, 0.4936507046f, 0.4915527403f, 0.0915199444f, 0.1035556868f, 0.4891586900f,
        0.4864699841f, 0.1155290529f, 0.1274328232f, 0.4834882319f, 0.4802152514f, 0.1392598450f,
        0.1510029733f, 0.4766530097f, 0.4728036523f, 0.1626551449f, 0.1742093414f, 0.4686695039f,
        0.4642530382f, 0.1856586039f, 0.1969960183f, 0.4595569372f, 0.4545840025f, 0.2082147747f,
        0.2193081230f, 0.4493372440f, 0.4438198209f, 0.2302693576f, 0.2410918921f, 0.4380350411f,
        0.4319864213f, 0.2517691851f, 0.2622948289f, 0.4256775975f, 0.4191123545f, 0.2726624906f,
        0.2828659117f, 0.4122946560f, 0.4052285850f, 0.2928989232f, 0.3027555346f, 0.3979184628f,
        0.3903686106f, 0.3124297559f, 0.3219157755f, 0.3825836182f, 0.3745681942f, 0.3312079012f,
        0.3403005004f, 0.3663271368f, 0.3578654230f, 0.3491881192f,
    },
    // esbr_alt_sin_twiddle_l64[32]=
    {
        0.0245338380f, 0.4993977249f, 0.0490085706f, 0.4975923598f, 0.0733652338f, 0.4945882559f,
        0.0975451618f, 0.4903926253f, 0.1214900911f, 0.4850156307f, 0.1451423317f, 0.4784701765f,
        0.1684449315f, 0.4707720280f, 0.1913417131f, 0.4619397521f, 0.2137775421f, 0.4519946575f,
        0.2356983721f, 0.4409606457f, 0.2570513785f, 0.4288643003f, 0.2777851224f, 0.4157347977f,
        0.2978496552f, 0.4016037583f, 0.3171966374f, 0.3865052164f, 0.3357794881f, 0.3704755604f,
        0.3535533845f, 0.3535533845f,
    },

    // esbr_sin_cos_twiddle_l32[32] =
    {0.0122706145f, 0.4998494089f, 0.4986452162f, 0.0367822833f, 0.0612053387f, 0.4962397814f,
     0.4926388264f, 0.0854809433f, 0.1095506176f, 0.4878510535f, 0.4818880260f, 0.1333563775f,
     0.1568408757f, 0.4747640789f, 0.4664964080f, 0.1799475253f, 0.2026206553f, 0.4571048915f,
     0.4466121495f, 0.2248056680f, 0.2464490980f, 0.4350434840f, 0.4224267900f, 0.2674988210f,
     0.2879040837f, 0.4087924063f, 0.3941732049f, 0.3076157868f, 0.3265864253f, 0.3786044121f,
     0.3621235490f, 0.3447702825f},

    // esbr_alt_sin_twiddle_l32[16] =
    {0.0490085706f, 0.4975923598f, 0.0975451618f, 0.4903926253f, 0.1451423317f, 0.4784701765f,
     0.1913417131f, 0.4619397521f, 0.2356983721f, 0.4409606457f, 0.2777851224f, 0.4157347977f,
     0.3171966374f, 0.3865052164f, 0.3535533845f, 0.3535533845f},

    // esbr_t_cos_sin_l32[32+32] = //exp[-i * pi/32* 3/4 * (k +0.5)]
    {

        0.4996611774f,  0.0184036121f,  0.4969534874f,  0.0551111028f,  0.4915527403f,
        0.0915199444f,  0.4834882319f,  0.1274328232f,  0.4728036523f,  0.1626551449f,
        0.4595569372f,  0.1969960183f,  0.4438198209f,  0.2302693576f,  0.4256775975f,
        0.2622948289f,  0.4052285850f,  0.2928989232f,  0.3825836182f,  0.3219157755f,
        0.3578654230f,  0.3491881192f,  0.3312079012f,  0.3745681942f,  0.3027555346f,
        0.3979184628f,  0.2726624906f,  0.4191123545f,  0.2410918921f,  0.4380350411f,
        0.2082147747f,  0.4545840025f,  0.1742093414f,  0.4686695039f,  0.1392598450f,
        0.4802152514f,  0.1035556868f,  0.4891586900f,  0.0672903508f,  0.4954513311f,
        0.0306603685f,  0.4990590513f,  -0.0061357692f, 0.4999623597f,  -0.0428986549f,
        0.4981563091f,  -0.0794290751f, 0.4936507046f,  -0.1155290529f, 0.4864699841f,
        -0.1510029733f, 0.4766530097f,  -0.1856586039f, 0.4642530382f,  -0.2193081230f,
        0.4493372440f,  -0.2517691851f, 0.4319864213f,  -0.2828659117f, 0.4122946560f,
        -0.3124297559f, 0.3903686106f,  -0.3403005004f, 0.3663271368f},
    {0.0163595416f, 0.4997322857f, 0.4975923598f, 0.0490085706f, 0.0814477354f, 0.4933216572f,
     0.4869384766f, 0.1135381311f, 0.1451423317f, 0.4784701765f, 0.4679529667f, 0.1761250198f,
     0.2063535154f, 0.4554319084f, 0.4409606457f, 0.2356983721f, 0.2640339136f, 0.4246010780f,
     0.4064233303f, 0.2912388444f, 0.3171966374f, 0.3865052164f, 0.3649320304f, 0.3417961597f},
    {0.0652630925f, 0.4957224429f, 0.1294095218f, 0.4829629064f, 0.1913417131f, 0.4619397521f,
     0.2500000000f, 0.4330126941f, 0.3043807149f, 0.3966766596f, 0.3535533845f, 0.3535533845f},
    {0.4994938970f,  0.0224907938f, 0.4954513311f,  0.0672903508f, 0.4873988628f,  0.1115453094f,
     0.4754016995f,  0.1548974812f, 0.4595569372f,  0.1969960183f, 0.4399927855f,  0.2375001907f,
     0.4168676436f,  0.2760821879f, 0.3903686106f,  0.3124297559f, 0.3607102036f,  0.3462486863f,
     0.3281324208f,  0.3772653341f, 0.2928989232f,  0.4052285850f, 0.2552949190f,  0.4299122095f,
     0.2156246901f,  0.4511163831f, 0.1742093414f,  0.4686695039f, 0.1313840449f,  0.4824295044f,
     0.0874954164f,  0.4922850430f, 0.0428986549f,  0.4981563091f, -0.0020453020f, 0.4999958277f,
     -0.0469727069f, 0.4977886677f, -0.0915199444f, 0.4915527403f, -0.1353264749f, 0.4813385010f,
     -0.1780377626f, 0.4672285914f, -0.2193081230f, 0.4493372440f, -0.2588035464f, 0.4278092086f},

    {0.0245338380f, 0.4993977249f, 0.4945882559f, 0.0733652338f, 0.1214900911f, 0.4850156307f,
     0.4707720280f, 0.1684449315f, 0.2137775421f, 0.4519946575f, 0.4288643003f, 0.2570513785f,
     0.2978496552f, 0.4016037583f, 0.3704755604f, 0.3357794881f},

    {0.0975451618f, 0.4903926253f, 0.1913417131f, 0.4619397521f, 0.2777851224f, 0.4157347977f,
     0.3535533845f, 0.3535533845f},

    {0.4990590513f,  0.0306603685f, 0.4915527403f,  0.0915199444f, 0.4766530097f,  0.1510029733f,
     0.4545840025f,  0.2082147747f, 0.4256775975f,  0.2622948289f, 0.3903686106f,  0.3124297559f,
     0.3491881192f,  0.3578654230f, 0.3027555346f,  0.3979184628f, 0.2517691851f,  0.4319864213f,
     0.1969960183f,  0.4595569372f, 0.1392598450f,  0.4802152514f, 0.0794290751f,  0.4936507046f,
     0.0184036121f,  0.4996611774f, -0.0428986549f, 0.4981563091f, -0.1035556868f, 0.4891586900f,
     -0.1626551449f, 0.4728036523f}};

const FLOAT32 long_window_sine_ld_64[IXHEAACE_QMF_CHANNELS] = {
    0.013038467f, 0.037573683f, 0.062086265f, 0.086561449f, 0.110984492f, 0.135340682f,
    0.159615347f, 0.183793867f, 0.207861675f, 0.231804276f, 0.255607246f, 0.279256248f,
    0.302737037f, 0.326035468f, 0.349137508f, 0.372029240f, 0.394696876f, 0.417126761f,
    0.439305384f, 0.461219386f, 0.482855568f, 0.504200894f, 0.525242510f, 0.545967738f,
    0.566364096f, 0.586419298f, 0.606121263f, 0.625458122f, 0.644418229f, 0.662990163f,
    0.681162736f, 0.698925003f, 0.716266263f, 0.733176071f, 0.749644241f, 0.765660853f,
    0.781216260f, 0.796301092f, 0.810906261f, 0.825022971f, 0.838642718f, 0.851757298f,
    0.864358811f, 0.876439667f, 0.887992588f, 0.899010616f, 0.909487113f, 0.919415769f,
    0.928790604f, 0.937605970f, 0.945856557f, 0.953537396f, 0.960643859f, 0.967171666f,
    0.973116885f, 0.978475935f, 0.983245588f, 0.987422970f, 0.991005566f, 0.993991217f,
    0.996378125f, 0.998164852f, 0.999350321f, 0.999933820f};

const FLOAT32 fft_twiddle_tab_32[IXHEAACE_QMF_TIME_SLOTS] = {
    0.000000f, 0.049068f, 0.098017f, 0.146730f, 0.195090f, 0.242980f, 0.290285f, 0.336890f,
    0.382683f, 0.427555f, 0.471397f, 0.514103f, 0.555570f, 0.595699f, 0.634393f, 0.671559f,
    0.740951f, 0.773010f, 0.803208f, 0.831470f, 0.857729f, 0.881921f, 0.903989f, 0.923880f,
    0.941544f, 0.956940f, 0.970031f, 0.980785f, 0.989177f, 0.995185f, 0.998795f, 0.000000f};

const FLOAT32 sbr_sin_cos_window[IXHEAACE_QMF_CHANNELS * 2] = {
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f,
    -0.70710678118f, 0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f,
    0.70710678118f,  0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,
    0.70710678118f,  -0.70710678118f, -0.70710678118f, 0.70710678118f,  0.70710678118f,
    -0.70710678118f, -0.70710678118f, 0.70710678118f};

const FLOAT32 cld_fb_64_640[CLD_FILTER_LENGTH] = {
    1.129580193872797e-002f,  2.353059744904218e-002f,  3.450718748721251e-002f,
    4.634695977000525e-002f,  5.918677345174197e-002f,  7.325978412117062e-002f,
    8.829745229234007e-002f,  1.042033024802571e-001f,  1.206924277410051e-001f,
    1.376149808913910e-001f,  1.547461142258783e-001f,  1.719726384566089e-001f,
    1.891590407342011e-001f,  2.062605107774960e-001f,  2.232276864673650e-001f,
    2.400768261284114e-001f,  2.568176309566753e-001f,  2.734977190313227e-001f,
    2.901491317310591e-001f,  3.068186515423912e-001f,  3.235298682841570e-001f,
    3.403074146062977e-001f,  3.571527896130669e-001f,  3.740643974275026e-001f,
    3.910243970160607e-001f,  4.080154903861317e-001f,  4.250144186334534e-001f,
    4.420013942269341e-001f,  4.589582896478246e-001f,  4.758753745532750e-001f,
    4.927463828072591e-001f,  5.095720854151864e-001f,  5.263554446856779e-001f,
    5.430990601899994e-001f,  5.598052330684253e-001f,  5.764734796907189e-001f,
    5.930981800982896e-001f,  6.096690552916387e-001f,  6.261725236758639e-001f,
    6.425939632009995e-001f,  6.589148753746076e-001f,  6.751199626157149e-001f,
    6.911981575264606e-001f,  7.071447728928043e-001f,  7.229599104052475e-001f,
    7.386515025302785e-001f,  7.542294504292890e-001f,  7.697093346240386e-001f,
    7.851012620144958e-001f,  8.004165237845137e-001f,  8.156523162880560e-001f,
    8.308039608112368e-001f,  8.458450064727010e-001f,  8.607492455327098e-001f,
    8.754640719350776e-001f,  8.899474405744183e-001f,  9.041286138017367e-001f,
    9.179666107725365e-001f,  9.313874086278087e-001f,  9.443802853939540e-001f,
    9.568885413848645e-001f,  9.690016637782843e-001f,  9.807691702375303e-001f,
    9.927543720639498e-001f,  1.001463112557766e+000f,  1.006893331637123e+000f,
    1.012508393574432e+000f,  1.017729040219375e+000f,  1.022470190536100e+000f,
    1.026615653698808e+000f,  1.030198648769593e+000f,  1.033205850580933e+000f,
    1.035694432087486e+000f,  1.037683165297586e+000f,  1.039227995800217e+000f,
    1.040349586463588e+000f,  1.041086497214721e+000f,  1.041443375950143e+000f,
    1.041434355650865e+000f,  1.041043184216171e+000f,  1.040262316588456e+000f,
    1.039061496136853e+000f,  1.037422300157921e+000f,  1.035311720204252e+000f,
    1.032712952177121e+000f,  1.029600494883906e+000f,  1.025966756910904e+000f,
    1.021798805583990e+000f,  1.017100128250049e+000f,  1.011867706519706e+000f,
    1.006109248754940e+000f,  9.998285752401580e-001f,  9.930379854679836e-001f,
    9.857387823493258e-001f,  9.779405164766706e-001f,  9.696426101291272e-001f,
    9.608519516143015e-001f,  9.515674613550604e-001f,  9.417975696327747e-001f,
    9.315442093447622e-001f,  9.208194746232827e-001f,  9.096310803629866e-001f,
    8.979959173503500e-001f,  8.859232320517536e-001f,  8.734366852542127e-001f,
    8.605542791988831e-001f,  8.472987145504696e-001f,  8.336863467961255e-001f,
    8.197387292306723e-001f,  8.054701312929008e-001f,  7.908995350037713e-001f,
    7.760385598209244e-001f,  7.609051036128973e-001f,  7.455111681431031e-001f,
    7.298745530879272e-001f,  7.140087729493950e-001f,  6.979336851549095e-001f,
    6.816667882498023e-001f,  6.652304141388827e-001f,  6.486437667370537e-001f,
    6.319284031798550e-001f,  6.151031151692835e-001f,  5.981877665956570e-001f,
    5.811992722116214e-001f,  5.641522833259215e-001f,  5.470652177576862e-001f,
    5.299509559653194e-001f,  5.128557121424191e-001f,  -4.956175421414453e-001f,
    -4.782650346610896e-001f, -4.609828932783459e-001f, -4.437530233023859e-001f,
    -4.265950246465440e-001f, -4.095160467543179e-001f, -3.925409172155113e-001f,
    -3.756821671788237e-001f, -3.589626517817934e-001f, -3.423942311297658e-001f,
    -3.259993851088293e-001f, -3.097861805973821e-001f, -2.937724988593393e-001f,
    -2.779637821990255e-001f, -2.623749159488041e-001f, -2.470098299603623e-001f,
    -2.318815478758375e-001f, -2.169925682529340e-001f, -2.023548005388463e-001f,
    -1.879711746686855e-001f, -1.738542127021508e-001f, -1.600061812296078e-001f,
    -1.464389150679625e-001f, -1.331544923127771e-001f, -1.201628679722633e-001f,
    -1.074630704470568e-001f, -9.506966959632511e-002f, -8.298103104739203e-002f,
    -7.120356992726613e-002f, -5.973741829536090e-002f, -4.859005767016811e-002f,
    -3.775928110298274e-002f, -2.726484300186575e-002f, -1.711323992709580e-002f,
    -7.298197371320593e-003f, 2.184256929356781e-003f,  1.132324047372148e-002f,
    2.012236990754980e-002f,  2.857528272530154e-002f,  3.666942822678171e-002f,
    4.439683978044157e-002f,  5.177964768870787e-002f,  5.881296711410786e-002f,
    6.550209046893848e-002f,  7.184073822817207e-002f,  7.783299328224960e-002f,
    8.347150698567406e-002f,  8.875756217893037e-002f,  9.368651761350569e-002f,
    9.826251129465624e-002f,  1.024804711677230e-001f,  1.063454554357498e-001f,
    1.098551252869576e-001f,  1.130180022553412e-001f,  1.158358935177899e-001f,
    1.183233335449968e-001f,  1.204854506722672e-001f,  1.223371395264402e-001f,
    1.238868653862843e-001f,  1.251477258491527e-001f,  1.261262023246478e-001f,
    1.268280540744526e-001f,  1.272498700590511e-001f,  1.273590703506806e-001f,
    1.274567595465545e-001f,  1.275561350483646e-001f,  1.273648326872248e-001f,
    1.269415772180714e-001f,  1.262995646340671e-001f,  1.254605188749804e-001f,
    1.244269583009826e-001f,  1.232131583108813e-001f,  1.218183974842866e-001f,
    1.202545652840080e-001f,  1.185243106889108e-001f,  1.166399102636992e-001f,
    1.146042249339280e-001f,  1.124296184976912e-001f,  1.101215600923314e-001f,
    1.076972053405737e-001f,  1.051641975499523e-001f,  1.025397604985405e-001f,
    9.982957934346254e-002f,  9.705239536075722e-002f,  9.421624116597689e-002f,
    9.133590931873967e-002f,  8.841813387276727e-002f,  8.547715661443602e-002f,
    8.251962055343706e-002f,  7.955570759229536e-002f,  7.657649751612349e-002f,
    7.360559211914287e-002f,  7.064948295960993e-002f,  6.771675107480543e-002f,
    6.480448458935215e-002f,  6.192692754258131e-002f,  5.911363249658311e-002f,
    5.637219228757212e-002f,  5.368313072045600e-002f,  5.105620793438655e-002f,
    4.849284995895640e-002f,  4.599068181839981e-002f,  4.355568588898841e-002f,
    4.125570251909672e-002f,  3.907137550527191e-002f,  3.696342556744636e-002f,
    3.493300140502248e-002f,  3.298151059524886e-002f,  3.110861245410919e-002f,
    2.931525594774175e-002f,  2.760090729801069e-002f,  2.597956638848436e-002f,
    2.443433592149451e-002f,  2.296470793543091e-002f,  2.156304510969632e-002f,
    2.023524610221679e-002f,  1.897505817503749e-002f,  1.778248750467421e-002f,
    1.665187994388476e-002f,  1.557759513377242e-002f,  1.456208586604537e-002f,
    1.361072086117313e-002f,  1.270747042064656e-002f,  1.186210743261470e-002f,
    1.106958962776399e-002f,  1.033126278863177e-002f,  9.640298325700842e-003f,
    8.996371481700806e-003f,  -8.407748878436545e-003f, -7.876393114319395e-003f,
    -7.380543918629573e-003f, -6.925141135202262e-003f, -6.500502521462604e-003f,
    -6.109178606718115e-003f, -5.741103163221257e-003f, -5.394569608919965e-003f,
    -5.063851046064050e-003f, -4.754191853611012e-003f, -4.448993249380505e-003f,
    -4.133639756278191e-003f, -3.811612348723333e-003f, -3.505531318950422e-003f,
    -3.209092846617964e-003f, -2.927159436740159e-003f, -2.653818578698405e-003f,
    -2.396404013961463e-003f, -2.152379960589273e-003f, -1.924844672908215e-003f,
    -1.699160580023900e-003f, -1.480542563288228e-003f, -1.283280633901446e-003f,
    -1.131859661378862e-003f, -9.730460256556873e-004f, -7.677634115875747e-004f,
    -5.599347984905645e-004f, -3.337966579125254e-004f, -9.099722643476421e-005f,
    1.498231621816041e-004f,  4.366447012116811e-004f,  6.307841647560053e-004f,
    6.150316826138937e-004f,  8.990255827053560e-004f,  1.232134364570107e-003f,
    1.471167206249042e-003f,  1.697652664777771e-003f,  1.985825255428654e-003f,
    2.172866052963961e-003f,  1.812176023993582e-003f,  1.344657262814793e-003f,
    9.373975348172919e-004f,  5.621720998949145e-004f,  2.048498552413189e-004f,
    -2.004822830002534e-004f, -6.169854804735951e-004f, -1.061498982103114e-003f,
    -1.594860949611097e-003f, -2.124647831574725e-003f, -2.621537051750861e-003f,
    -3.064311083207632e-003f, -3.460362845825662e-003f, -3.794425324215804e-003f,
    -4.091032597247918e-003f, -4.369553676668050e-003f, -4.554811297024067e-003f,
    -4.663276675479689e-003f, -4.722567636185647e-003f, -4.704321497976561e-003f,
    -4.636227793039124e-003f, -4.517190210387324e-003f, -4.351667566540186e-003f,
    -4.135130493071822e-003f, -3.870851645947402e-003f, -3.597475533950260e-003f,
    -3.318857985461042e-003f, -3.000422543655664e-003f, -2.658042081080524e-003f,
    -2.292813563887493e-003f, -1.914114740669928e-003f, -1.525818616748839e-003f,
    -1.156680209049319e-003f, -7.804546272743493e-004f, -4.268574601396473e-004f,
    -1.324291707264515e-004f, 1.218226450050751e-004f,  3.189336138130849e-004f,
    4.749931197951235e-004f,  5.970696819774243e-004f,  6.673250213055329e-004f,
    6.887783835812338e-004f,  6.766320515830324e-004f,  6.944123176012471e-004f,
    7.139919634325070e-004f,  7.154123487609100e-004f,  7.376101027486600e-004f,
    6.976561203768226e-004f,  5.721223454434728e-004f,  2.934875643581191e-004f,
    1.092526149391273e-004f,  6.415402443848103e-004f,  1.194730618383423e-003f,
    1.557112059887280e-003f,  1.891971801393744e-003f,  2.225524159129023e-003f,
    2.530906981099261e-003f,  2.719749515067397e-003f,  2.729136737522100e-003f,
    2.703019498899013e-003f,  2.630471852319136e-003f,  2.470456304276468e-003f,
    2.239142906871446e-003f,  2.033465291493264e-003f,  1.948069005335563e-003f,
    1.725029670030533e-003f,  1.417366709895927e-003f,  1.127141815310061e-003f,
    8.089811988213151e-004f,  4.708009521678285e-004f,  7.882620739833088e-005f,
    -2.998739993995956e-004f, -4.733148292475610e-004f, -5.791145447913150e-004f,
    -6.754935404082003e-004f, -8.029620210721900e-004f, -9.726698841994444e-004f,
    -1.196637962311630e-003f, -1.292865844760059e-003f, -1.146268465739874e-003f,
    -1.040598055074471e-003f, -9.767709065548874e-004f, -9.294665200453614e-004f,
    -9.862027119530482e-004f, -1.047654674829846e-003f, -1.099000599887377e-003f,
    -1.151795860160292e-003f, -1.194743370333155e-003f, -1.250742797799558e-003f,
    1.287819050086379e-003f,  1.263569296641556e-003f,  1.226113111394085e-003f,
    1.177515087338257e-003f,  1.122503050159859e-003f,  1.089428846944533e-003f,
    1.054963366189962e-003f,  9.019128558297515e-004f,  7.847839620863715e-004f,
    6.205675927856794e-004f,  3.157663628445906e-004f,  2.556449844935384e-004f,
    2.520606580606257e-004f,  2.346980949474655e-004f,  2.060394037017961e-004f,
    1.635905995590986e-004f,  1.176237128375623e-004f,  6.193369904730005e-005f,
    3.568554800150508e-005f,  2.443161189273522e-005f,  1.334090914042349e-005f,
    2.853437194757816e-006f,  -1.039263591111469e-004f, 5.144969377044875e-005f,
    9.711681816385056e-005f,  2.472023910553232e-005f,  5.397064424090302e-005f,
    6.487880719449901e-005f,  -5.192444140699947e-005f, -9.204876089551197e-005f,
    -1.815837353167847e-004f, -3.595054179561440e-004f, -5.901617707607606e-007f,
    1.831121301698088e-004f,  9.755685190624611e-005f,  6.606461762989423e-005f,
    3.799971890923797e-005f,  4.150075391929448e-005f,  5.021905476506264e-005f,
    5.861800137434713e-005f,  2.126364641291926e-005f,  1.181077582797280e-004f,
    9.990757789944374e-005f,  1.035782617124906e-004f,  8.870181845310037e-005f,
    5.533953373249822e-005f,  1.580188994455254e-005f,  1.277184430250593e-006f,
    5.009913312943629e-006f,  1.499170392246774e-005f,  2.241545750231630e-005f,
    3.628511258723260e-005f,  2.406516798531014e-005f,  2.515118233957011e-005f,
    3.759629789955498e-005f,  5.408154543124121e-005f,  4.493916063285122e-005f,
    2.806963579578946e-005f,  2.364518513682831e-005f,  1.260639764582286e-005f,
    -2.599467772603631e-008f, -1.774108392496017e-005f, -5.889276659458115e-006f,
    -4.663777919108619e-005f, -2.078886359425321e-004f, -2.131405580107761e-004f,
    -1.784192600231068e-004f, -1.744841754193053e-004f, -1.728672507238372e-004f,
    -1.885286127508226e-004f, -2.078299015661617e-004f, -2.123671573189573e-004f,
    -2.415166002501312e-004f, -2.217025456251449e-004f, -9.907630821710970e-005f,
    -8.039231481768845e-005f, -7.934509417722400e-005f, -5.874199358780108e-005f,
    -5.449816072329412e-005f, -4.489491034408147e-005f, -3.498285982359981e-005f,
    -1.748284921486958e-005f, -9.075430772832575e-006f, -1.052707430241351e-005f,
    -6.538878366985722e-006f, 2.206341308073472e-005f,  1.769261935287328e-004f,
    6.418658561385058e-005f,  -8.882305312548962e-005f, -1.721347222211949e-005f,
    -6.093372716385583e-005f, -7.679955330373515e-005f, 7.194151087015007e-005f,
    7.245095937243279e-005f,  7.870354371072524e-005f,  5.822201682995846e-004f,
    2.666444630171025e-004f,  7.872592352725688e-005f,  7.095886893185526e-005f,
    5.643103068471008e-005f,  6.904415362098980e-005f,  4.694251739991356e-005f,
    3.367998338617662e-005f,  6.481921021601837e-005f,  6.582328030188790e-005f,
    -4.256442530773449e-005f, 4.939392400898679e-005f,  5.272982009116034e-005f,
    4.005269212731273e-005f,  2.461876679726978e-005f,  4.469729032194765e-006f,
    3.798519731621893e-007f,  1.374896222030490e-006f,  3.965363805500215e-006f,
    7.300588863934780e-006f,  1.168894474770061e-005f,  8.563819899447630e-006f,
    8.975977837330335e-006f,  2.800455533708622e-005f,  2.015445311139832e-005f,
    1.125134651175812e-005f,  5.869707265615299e-006f,  1.013259758329981e-005f,
    1.088325131492173e-005f,  7.167101260771279e-006f,  4.840577540089826e-006f,
    -1.469933448634890e-005f, -8.010079089953001e-006f, -3.299004046633323e-005f,
    -4.373302115187172e-005f, -3.177468256997963e-005f, -2.976824036182567e-005f,
    -2.464228015326852e-005f, -1.606050838620834e-005f, -6.261944255489322e-006f,
    4.591009581217994e-007f,  1.395220723090848e-005f,  1.622786214398703e-005f,
    -2.043464113212971e-006f, -1.653463907257247e-006f, -1.551250801467300e-008f,
    -1.907927361317977e-006f, -9.607068622268791e-007f, -4.636105364510011e-007f,
    -2.765649762593200e-007f, -1.922074581855119e-006f, -9.897194091136331e-007f,
    -7.873304717454037e-008f, 2.945239208477290e-008f,  -2.757610624807679e-006f,
    -1.402925247695813e-005f, -9.388962780643742e-006f, 2.068297421740023e-005f,
    1.496435902895210e-007f,  6.757014945674924e-009f,  -2.778618354859861e-007f,
    -1.569003268449803e-006f, -1.089500601234349e-006f, -9.870547653835426e-007f,
    3.867483283567218e-005f,  -1.232693496472088e-005f, 9.464782951082177e-007f,
    8.254429452094225e-007f,  4.883304950437536e-007f,  -2.066961713890010e-007f,
    5.158212471036245e-009f,  2.267731106642486e-007f,  -4.880844550713951e-008f,
    3.361682183852576e-006f,  4.677015459111491e-006f,  2.820292122791583e-008f,
    5.143614846654519e-007f,  3.818588614859347e-009f,  1.737276553950212e-007f,
    1.876022048145804e-007f,  -2.986488593070417e-009f, -1.409927495646886e-008f,
    -6.977078748707401e-008f, -1.280675520205100e-008f, -2.222072007942510e-009f,
    -1.775191290895584e-009f, -1.686136654621906e-009f, 5.818594642226675e-006f,
    2.150883991167946e-006f,  2.714879009950152e-007f,  -2.567964804401197e-008f,
    2.041128570435378e-006f,  3.262753594084781e-006f,  3.567581483749161e-006f,
    4.083718802566134e-006f,  5.364807253588177e-006f,  4.178050149840223e-006f,
    5.189086332701670e-006f,  3.357218747491756e-006f,  6.310207878018869e-006f,
    5.924001540927652e-006f,  5.161606640348293e-006f,  3.377814811745950e-006f,
    1.323267689777069e-006f,  -1.074716688428712e-007f, -3.561585382456484e-006f,
    -4.518603099564185e-006f, 7.301956971603966e-007f,  5.891904775161025e-007f,
    2.801882088134371e-008f,  6.322770332405526e-007f,  2.542598385847351e-007f,
    1.272704908592385e-007f,  8.226599990523664e-008f,  5.433718768789140e-007f,
    4.211177232106135e-007f,  3.552991527555180e-008f,  -1.398913109540774e-008f,
    1.356727552196146e-006f,  -1.706941020342299e-005f, 1.013575160981381e-005f,
    -2.285562946018590e-005f, -8.908041185396514e-008f, -9.597515277415496e-009f,
    -3.225913527455964e-007f, 1.070242712585309e-006f,  6.293002327021578e-007f,
    3.575650976036433e-007f,  2.722295965060517e-005f,  8.676848186676888e-006f,
    3.428660858940255e-007f,  4.767793949944890e-007f,  3.330981930777764e-007f,
    2.399696144635756e-007f,  7.326611439066549e-009f,  1.349943693297681e-007f,
    -5.393555749348494e-008f, 3.629067065524143e-006f,  -5.690530948134642e-006f,
    1.387566465624550e-008f,  2.443085172403935e-007f,  1.723217058490933e-009f,
    7.391973323448250e-008f,  5.303527922331415e-008f,  -8.883499047404846e-010f,
    -3.870536804891648e-009f, -1.846547564287500e-008f, -4.244090917065736e-009f,
    -4.013524925634108e-009f, -6.325664562585882e-010f, -6.025110605409611e-010f,
    1.620171502086309e-006f,  5.490569954646963e-007f,  6.355303179925355e-008f,
    -5.426597100684762e-009f, 4.292861814894369e-007f,  6.834209542421138e-007f,
    7.099633014995863e-007f,  8.109951846981774e-007f,  4.118359768898598e-007f,
    6.571760029213382e-007f};

const WORD32 ixheaace_ld_env_tab_512[16][4] = {
    {2, 4, -1, 0},  {2, 5, -1, 0},  {3, 2, 6, 1},   {3, 3, 7, 1},
    {3, 4, 8, 1},   {3, 5, 9, 1},   {3, 6, 10, 1},  {3, 7, 11, 1},
    {3, 8, 12, 1},  {3, 9, 13, 1},  {3, 10, 14, 1}, {2, 11, -1, 1},
    {2, 12, -1, 1}, {2, 13, -1, 1}, {2, 14, -1, 1}, {2, 15, -1, 1},
};

const WORD32 ixheaace_ld_env_tab_480[15][4] = {
    {2, 4, -1, 0},  {2, 5, -1, 0},  {3, 2, 6, 1},   {3, 3, 7, 1},   {3, 4, 8, 1},
    {3, 5, 9, 1},   {3, 6, 10, 1},  {3, 7, 11, 1},  {3, 8, 12, 1},  {3, 9, 13, 1},
    {2, 10, -1, 1}, {2, 11, -1, 1}, {2, 12, -1, 1}, {2, 13, -1, 1}, {2, 14, -1, 1},
};
